% Averaging demonstrations
% 5/26/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Create time vector and frequency vector
Nt=2^16;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector

% Reset the state of random number generator
randn('state',sum(100*clock));

% Create sinusoidal signal with random noise
y=sin(2*pi*10*t)+2*randn(Nt,1);

% Perform cyclic averaging
BS=1024;
navg=Nt/BS;
yavg=zeros(BS,1);
for ii=1:navg,
    yavg=yavg+y(1+(ii-1)*BS:ii*BS);
end
yavg=yavg/navg;

% Perform asynchronous averaging
BS2=BS-round(BS/3);
navg=round(Nt/BS2);
yavga=zeros(BS2,1);
for ii=1:navg-1,
    yavga=yavga+y(1+(ii-1)*BS2:ii*BS2);
end
yavga=yavga/navg;

% Plot results
figure(1);
subplot(211);
plot(t,y,'k-');
xlabel('Time [sec]');
ylabel('y(t)');
axis([0 2 -5 5]);
subplot(223);
plot(t(1:BS),yavg,'k-');
xlabel('Time [sec]');
ylabel('y_{avg}(t)');
axis([0 2 -5 5]);
subplot(224);
plot(t(1:BS2),yavga,'k-');
xlabel('Time [sec]');
ylabel('y_{avg}(t)');
axis([0 2 -5 5]);

% Continue on with example using two DOF system
disp('Press any key to continue:');
pause;

% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
BS=1024*4;
f1=10*sin(2*pi*20/t(BS)*t)+100*sin(2*pi*40/t(BS)*t)+100*sin(2*pi*29/t(BS)*t)+20*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xb1=x1;
xb2=x2;

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=10*sin(2*pi*20/t(BS)*t)+100*sin(2*pi*40/t(BS)*t)+100*sin(2*pi*29/t(BS)*t)+20*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

x1d1=x1;
x1d2=x2;

% Perform cyclic averaging for DFT
f=(0:1/t(BS):(BS-1)/t(BS))';
navg=round(Nt/BS-1);
xb1a=zeros(BS,1);
xd1a=zeros(BS,1);
for ii=1:navg,
    xb1a=xb1a+xb1(1+(ii-1)*BS:ii*BS);
    xd1a=xd1a+x1d1(1+(ii-1)*BS:ii*BS);
end

% Define P301 window function
ftv=linspace(-0.5,0.5,BS)';
wind=0.9994484+2*(0.955728*cos(2*pi*1*ftv)+0.539289*cos(2*pi*2*ftv)+0.091581*cos(2*pi*3*ftv));
wind=hanning(BS);

% Plot results
figure(2);
subplot(221);
semilogy(f,abs(fft(xb1a.*wind))/BS/2,'k-',f,abs(fft(xd1a.*wind))/BS/2,'k--');
xlabel('Freq [Hz]');
ylabel('X_{avg}(f) [m]');
xlim([0 3]);
ylim([1e-4 1e1]);

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20-20*0.50;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=10*sin(2*pi*20/t(BS)*t)+100*sin(2*pi*40/t(BS)*t)+100*sin(2*pi*29/t(BS)*t)+20*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

x2d1=x1;
x2d2=x2;

% Perform cyclic averaging for DFT
f=(0:1/t(BS):(BS-1)/t(BS))';
navg=round(Nt/BS-1);
xb1a=zeros(BS,1);
xd1a=zeros(BS,1);
for ii=1:navg,
    xb1a=xb1a+xb1(1+(ii-1)*BS:ii*BS);
    xd1a=xd1a+x2d1(1+(ii-1)*BS:ii*BS);
end

figure(2);
subplot(222);
semilogy(f,abs(fft(xb1a.*wind))/BS/2,'k-',f,abs(fft(xd1a.*wind))/BS/2,'k--');
xlabel('Freq [Hz]');
ylabel('X_{avg}(f) [m]');
xlim([0 3]);
ylim([1e-4 1e1]);

% Define new input blocksize
BS2=1*BS+round(1*BS/sqrt(15));

% Perform cyclic averaging for DFT
f=(0:1/t(BS2):(BS2-1)/t(BS2))';
navg=round(Nt/BS2-1);
xb1a=zeros(BS2,1);
xd1a=zeros(BS2,1);
for ii=1:navg,
    xb1a=xb1a+xb1(1+(ii-1)*BS2:ii*BS2);
    xd1a=xd1a+x1d1(1+(ii-1)*BS2:ii*BS2);
end

% Define P301 window function
ftv=linspace(-0.5,0.5,BS2)';
wind=0.9994484+2*(0.955728*cos(2*pi*1*ftv)+0.539289*cos(2*pi*2*ftv)+0.091581*cos(2*pi*3*ftv));
wind=hanning(BS2);

% Plot results
figure(2);
subplot(223);
semilogy(f,abs(fft(xb1a.*wind))/BS2/2,'k-',f,abs(fft(xd1a.*wind))/BS2/2,'k--');
xlabel('Freq [Hz]');
ylabel('X_{avg}(f) [m]');
xlim([0 3]);
ylim([1e-4 1e1]);

% Perform cyclic averaging for DFT
f=(0:1/t(BS2):(BS2-1)/t(BS2))';
navg=round(Nt/BS2-1);
xb1a=zeros(BS2,1);
xd1a=zeros(BS2,1);
for ii=1:navg,
    xb1a=xb1a+xb1(1+(ii-1)*BS2:ii*BS2);
    xd1a=xd1a+x2d1(1+(ii-1)*BS2:ii*BS2);
end

figure(2);
subplot(224);
semilogy(f,abs(fft(xb1a.*wind))/BS2/2,'k-',f,abs(fft(xd1a.*wind))/BS2/2,'k--');
xlabel('Freq [Hz]');
ylabel('X_{avg}(f) [m]');
xlim([0 3]);
ylim([1e-4 1e1]);