% Modeling broadband random excitations
% 4/16/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Define signal parameters
t=(0:.001:9.999)';
fv=(0:1/9.999:9999/9.999)';
fr=randn(10000,1);
f=2*cos(2*pi*5.5*t)+2*sin(2*pi*6.5*t)+2*cos(2*pi*4.0*t)+2*fr;

% Plot signal
figure(1);
subplot(221);
plot(t,f,'k');
axis([0 2 -15 15]);
xlabel('Time [sec]');
ylabel('f(t) [N]');
subplot(222);
semilogy(fv,abs(fft(f)/10000),'k');
xlabel('Freq [Hz]');
ylabel('F(\omega) [N]');
axis([0 10 1e-3 1e0]);

% Compute Fourier spectra
F=fft(f)/10000;
Gff=F.*conj(F);
Sff=Gff/fv(2);

% Compute signal parameters
msv=mean(f.^2);
sum(abs(Sff)*fv(2));
mu=mean(f);
varn=sum(abs(Sff)*fv(2))-mu^2;

% Plot distribution 
subplot(212);
fg=linspace(-5,5,100);
plot(fg,1/sqrt(varn)/sqrt(2*pi)*exp(-(fg-mu).^2)/2/varn,'k');
xlabel('f [N]');
ylabel('p(f)');