% Filtering demo
% Demonstrate beamforming using phased array
% 6/14/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Establish parameters
nn=input('Number of sensors: ');  % Get No. of sensors
nw=2;                             % No. of rows
lambda=1;                         % Wavelength of the sensors arriving
throw_out_sens=1;                 % Throw out sensors
qnumber=1;                        % Nomenclature from Widrow and Stearns (1985)
bc=[2,4,6];                       % Sensors to be thrown out

% Generating the weight vector
w=ones(nn,2);
w(:,1)=1/sqrt(2)+j/sqrt(2); 
w(:,2)=1/sqrt(2)-j*sqrt(2);
w(:,2)=0; 
w(:,1)=w(:,1)/(nn-max(size(bc))); 

% Remove some sensors from the array to examine effects
if throw_out_sens==1
    w(bc,:)=zeros(length(bc),size(w,2));    % Set weights to zero for sensors
end;

% Generating the polar spatial power envelop
tempp=input('Sensor Spacing: lambda/? ');   % Get spacing from user
spacing=lambda/tempp;             % Interelement spacing
L=(0:nn-1)'*spacing;              % Distance of sensor i from sensor 0 (uniform spacing for plane wave)
theta=-pi:0.01:pi;                % Angular positions for computing array factor power envelope

for m=[0:1:135 135:-1:45 45:1:90],  % Loop through various desired steering angles

    phfactor=2*pi*L/lambda;       % Phase angle lost as a result of distance from sensor-to-sensor
    ax=zeros(size(theta));        % Intitialise gain
    zi=[m]*pi/180;                % Desired look direction for sensor array
    pdelay=phfactor*cos(zi);      % Necessary phase delay for each sensor channel (this is tap delay or d(m,omega)=exp(-j*pdelay))
    for ii=1:nn,
        temp=-phfactor(ii)*cos(theta)+pdelay(ii);             % Compute total phase delay including arrival and time shift
        ax=ax+w(ii,1)*exp(j*temp)+w(ii,2)*exp(-j*temp);       % Compute array factor for output of beamsteering array of sensors
    end
    gain=abs(ax);                                             % Compute again and normalize by number of sensors
    figure(1);
    subplot(122); 
    polar(theta,gain,'b-');
    titel=['Polar Plot','  ','Steering Angle: ',int2str(m)]; title(titel);
    subplot(121); 
    plot(theta*180/pi,gain,'b-'); 
    axis([0 180 0 1]);
    xlabel('\theta [deg]'); 
    ylabel('Array Factor Gain, |AF( \theta)|');
    pause(0.05);
end