% Filtering demo
% Demonstrate time, frequency, and spatial filters
% 6/14/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
Nt=5000;
dt=0.001;
t=(0:dt:(Nt-1)*dt)';

% Signal definition
y1=2*sin(2*pi*10*t)+sin(2*pi*50*t);
y1=y1+0.3*randn(Nt,1);
y1(2000:2500)=y1(2000:2500)/2;
y1(3500:4000)=y1(3500:4000)/5;
y1(100:300)=y1(100:300)+4*exp(-(0:200)/601)';

% Saturate response level
for ii=1:5000,
    if y1(ii)>5,
        y1(ii)=5;
    end
end

% Filter
Npts=50;
for ii=1:99,
    y1f(1+Npts*(ii-1):Npts+Npts*ii)=y1(1+Npts*(ii-1):Npts+Npts*ii)/max((abs(y1(1+Npts*(ii-1):Npts+Npts*ii).^1)));
end

% Plot results
figure(1);
subplot(211);
plot(t,y1,'k-');
axis([0 5 -8 8]);
xlabel('Time [s]');
ylabel('y [V]');
subplot(212);
plot(t,y1f,'k-');
axis([0 5 -2 2]);
xlabel('Time [s]');
ylabel('y [V]');

% Interpolate using low pass filter
y1i=interp(y1,2);
Nt2=10000;
dt2=0.001/2;
t2=(0:dt2:(Nt2-1)*dt2)';

% Decimate using low pass filter and resampling
y1d=decimate(y1,2);
Nt3=2500;
dt3=0.001*2;
t3=(0:dt3:(Nt3-1)*dt3)';

figure(2);
subplot(211);
plot(t,y1,'kx-',t2,y1i,'ko-');
axis([1.02 1.03 1 4]);
xlabel('Time [s]');
ylabel('y [V]');
subplot(212);
plot(t,y1,'kx-',t3,y1d,'ko-');
axis([1.02 1.03 1 4]);
xlabel('Time [s]');
ylabel('y [V]');

% Continue
disp('Press any key to continue');
pause;

% Demonstrate spatial filter
% using two DOF system model

% Parameters
m1=1;
m2=1;
k1=10;
k2=20;
k3=10;

% Generate matrices
M=[m1 0;0 m2];
K=[k1+k2 -k2; -k2 k2+k3];
C=.01*M+.01*K;
c1=C(1,1)+C(1,2);
c2=-C(1,2);
c3=C(2,2)+C(2,1);
A=[zeros(2) eye(2);-inv(M)*K -inv(M)*C];
B=[0 0 1 0]';

[v,d]=eig(A);
shp2=real(v(1:2,3)/max(v(1:2,3)));
shp1=real(v(1:2,1)/max(v(1:2,1)));

% Set initial conditions
% Use an initial condition on the velocity to simluate impact
x10=0;
xd10=0;
x20=0;
xd20=0;

% Generate system in MATLAB
sys=ss(A,B,[eye(4)],zeros(4,1));

% Simulate response
Nt=20480;
dt=.001;
t=(0:dt:(Nt-1)*dt)';
f1=rand(Nt,1);
f1=f1-mean(f1);
[x,t]=lsim(sys,f1,t,[x10 x20 xd10 xd20]');

% Plot filtered modal responses
figure(3);
subplot(211);
plot(t,x(:,1),'k-',t,x(:,2),'k--');
axis([0 20 -.008 .008]);
xlabel('Time [s]');
ylabel('x_1 and x_2 [m]');
subplot(212);
plot(t,shp1(1)*x(:,1)/sqrt(sum(shp1.^2))+shp1(2)*x(:,2)/sqrt(sum(shp2.^2)),'k-',t,shp2(1)*x(:,1)/sqrt(sum(shp1.^2))+shp2(2)*x(:,2)/sqrt(sum(shp2.^2)),'k--');
xlabel('Time [s]');
ylabel('Filtered Responses [m]');
axis([0 20 -.008 .008]);

% Continue
disp('Press any key to continue');
pause;

% Generate digital filter frequency response
load bpassfilt
sys=filt(Num1,Den1);
w=(0:.01:pi)';
[m,p]=bode(sys,w);
figure(4);
subplot(211);
semilogy(w/pi*2500,squeeze(m(1,1,:)),'k.-');
xlabel('Frequency [Hz]');
ylabel('Magnitude');
subplot(212);
plot(w/pi*2500,squeeze(p(1,1,:)),'k.-');
xlabel('Frequency [Hz]');
ylabel('Phase [deg]');

% Generate digital filter frequency response
load bpassfilt2
sys=filt(Num2,Den2);
w=(0:.01:pi)';
[m,p]=bode(sys,w);
figure(5);
subplot(211);
semilogy(w/pi*2500,squeeze(m(1,1,:)),'k.-');
xlabel('Frequency [Hz]');
ylabel('Magnitude');
subplot(212);
plot(w/pi*2500,squeeze(p(1,1,:)),'k.-');
xlabel('Frequency [Hz]');
ylabel('Phase [deg]');