% Frequency response function estimation
% 5/28/06 
% 2006 Copyright D. E. Adams

clear all;
close all;


% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:2,1:2,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=20*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xb1=x1;
xb2=x2;

% Estimate FRFs
navg=50;
ovlap=.5;
[H11,C11]=rfrf(f1,xb1,navg,ovlap);
[H21,C21]=rfrf(f1,xb2,navg,ovlap);
f=(0:1/t(max(size(H11))):(max(size(H11))-1)/t(max(size(H11))))';

% Plot results
figure(1);
subplot(321);
semilogy(w/2/pi,abs(squeeze(H(1,1,:))),'k--',f,abs(H11),'k-');
xlabel('Freq [Hz]');
ylabel('Mag. H_{11} [m/N]');
xlim([0 3]);
subplot(322);
semilogy(w/2/pi,abs(squeeze(H(2,1,:))),'k--',f,abs(H21),'k-');
xlabel('Freq [Hz]');
ylabel('Mag. H_{21} [m/N]');
xlim([0 3]);
subplot(323);
plot(w/2/pi,180/pi*unwrap(angle(squeeze(H(1,1,:)))),'k--',f,180/pi*unwrap(angle(H11)),'k-');
xlim([0 3]);
xlabel('Freq [Hz]');
ylabel('Phs. H_{11} [deg]');
subplot(324);
plot(w/2/pi,180/pi*unwrap(angle(squeeze(H(2,1,:)))),'k--',f,180/pi*unwrap(angle(H21)),'k-');
xlim([0 3]);
xlabel('Freq [Hz]');
ylabel('Phs. H_{21} [deg]');
subplot(325);
plot(f,abs(C11),'k-');
xlim([0 3]);
ylim([0 1]);
xlabel('Freq [Hz]');
ylabel('C_{11}');
subplot(326);
plot(f,abs(C21),'k-');
xlim([0 3]);
ylim([0 1]);
xlabel('Freq [Hz]');
ylabel('C_{21}');