% Lumped parameter nine degree of freedom plate model
% Changes due to environmental factors
% May 13, 2006
% 2006 Copyright D. E. Adams

clear all;
close all;

% Define parameters and model matrices
k=1e7;
m=0.2;
M=diag([m m m m m m m m m]);
SOk=100;     % boundary condition springs
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Generate frequency response function
Nf=5000; Ff=5000; % Number of frequency lines and frequency bandwidth
H=zeros(9,9,Nf);
f=linspace(0,Ff,Nf); % Generate frequency vector
a=.001; b=.00001; % Define coefficients for proportional damping model
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C);
end

% Perturb plate (in terms of mass)
M=diag([m+0.1*m m+0.1*m m+0.1*m m+0.1*m m+0.1*m m+0.1*m m+0.1*m m+0.1*m m+0.1*m]); % Simulate change in mass due to absorption
C=a*M+b*K; % Generate modified proportional viscous damping model
Hd=zeros(9,9,Nf);
for ii = 2:Nf,
    He(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C);
end

% Perturb plate (by softening the stiffness due to temperature)
M=diag([m m m m m m m m m]);
SOk=100;     % Boundary condition springs
k=k-0.10*k   % Simulate change in stiffness due to temperature change
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];
C=a*M+b*K; % Generate modified proportional viscous damping model
Hd=zeros(9,9,Nf);
for ii = 2:Nf,
    He2(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C);
end

% Plot the baseline and modified FRFs due to environmental factors
figure(1);
subplot(211);
semilogy(f,abs(squeeze(H(1,1,:))),'k-',f,abs(squeeze(He(1,1,:))),'k:')
xlabel('Frequency [Hz]'); ylabel('Mag H_{11}(\omega) [m/N]');
legend('Baseline','10% mass increase');
axis([0 5000 1e-10 1e-5]);
subplot(212);
semilogy(f,abs(squeeze(H(1,1,:))),'k-',f,abs(squeeze(He2(1,1,:))),'k:')
xlabel('Frequency [Hz]'); ylabel('Mag H_{11}(\omega) [m/N]');
legend('Baseline','10% stiffness decrease');
axis([0 5000 1e-10 1e-5]);
