% Lumped parameter nine degree of freedom plate model
% Feature extraction
% July 15, 2006
% 2006 Copyright D. E. Adams

clear all;
close all;

% Define parameters and model matrices
k=1e7;
m=0.2;
M=diag([m m m m m m m m m]);
SOk=100;     % boundary condition springs
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Reset the state of random number generator
randn('state',randn*sum(100*clock));

% Generate frequency response function
Nf=5000; Ff=5000; % Number of frequency lines and frequency bandwidth
H=zeros(9,9,Nf);
f=linspace(0,Ff,Nf); % Generate frequency vector
a=.001; b=.00001; % Define coefficients for proportional damping model
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,1)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Perturb plate (either in terms of mass or stiffness)
M=diag([m-0.1*m m m m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,2)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m-0.1*m m m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,3)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m-0.1*m m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,4)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m-0.1*m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,5)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m-0.1*m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,6)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m-0.1*m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,7)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m m-0.1*m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*randn(9);
end
Hf(:,8)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m m m-0.1*m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*randn(9);
end
Hf(:,9)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m m m m-0.1*m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,10)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

Hf1=Hf;

% Plot the baseline and damaged FRFs
figure(1);
subplot(311);
semilogy(f,squeeze(abs(H(1,1,:))),'k');
ylim([1e-9 1e-3]);
xlim([0 2500]);
xlabel('Frequency [Hz]'); ylabel('Mag H_{11}(\omega) [m/N]');
subplot(3,9,10);
plot(Hf(:,2)./Hf(:,1),'kx');
xlabel('Feature'); ylabel('Value [m/N]');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,11);
plot(Hf(:,3)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,12);
plot(Hf(:,4)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,13);
plot(Hf(:,5)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,14);
plot(Hf(:,6)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,15);
plot(Hf(:,7)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,16);
plot(Hf(:,8)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,17);
plot(Hf(:,9)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(3,9,18);
plot(Hf(:,10)./Hf(:,1),'kx');
ylim([0.5 1.05]);
xlim([0 6]);
subplot(313);
plot(1:9,sum(Hf(:,2:10))/sum(Hf(:,1)),'kx');
xlabel('Damage Case'); ylabel('Value [m/N]');
xlim([0 10]);
ylim([0.5 1]);

% Location algorithm using dot product
M=diag([m m m m m m m m m]);
SOk=100;     % boundary condition springs
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Generate frequency response function
Nf=5000; Ff=5000; % Number of frequency lines and frequency bandwidth
H=zeros(9,9,Nf);
f=linspace(0,Ff,Nf); % Generate frequency vector
a=.001; b=.00001; % Define coefficients for proportional damping model
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,1)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Perturb plate (either in terms of mass or stiffness)
M=diag([m-0.1*m m m m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,2)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m-0.1*m m m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,3)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m-0.1*m m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,4)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m-0.1*m m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,5)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m-0.1*m m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,6)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m-0.1*m m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,7)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m m-0.1*m m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,8)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m m m-0.1*m m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,9)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

M=diag([m m m m m m m m m-0.1*m]); % Simulate damage to density (corrosion)
C=a*M+b*K; % Generate damaged proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*abs(1-0.1*randn(9));
end
Hf(:,10)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

% Plot projection features for damage location
figure(2);
ymin2=.9;
ymax2=1.1;
ymax1=1.1
ymin1=.9;
subplot(5,2,1);
plot([sum(Hf(:,1).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,2).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,3).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,4).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,5).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,6).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,7).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,8).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,9).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1)) sum(Hf(:,10).*Hf(:,1))/sum(Hf(:,1).*Hf(:,1))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,2);
plot([sum(Hf(:,1).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,2).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,3).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,4).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,5).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,6).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,7).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,8).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,9).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2)) sum(Hf(:,10).*Hf(:,2))/sum(Hf(:,2).*Hf(:,2))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,3);
plot([sum(Hf(:,1).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,2).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,3).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,4).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,5).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,6).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,7).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,8).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,9).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3)) sum(Hf(:,10).*Hf(:,3))/sum(Hf(:,3).*Hf(:,3))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,4);
plot([sum(Hf(:,1).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,2).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,3).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,4).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,5).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,6).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,7).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,8).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,9).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4)) sum(Hf(:,10).*Hf(:,4))/sum(Hf(:,4).*Hf(:,4))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,5);
plot([sum(Hf(:,1).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,2).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,3).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,4).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,5).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,6).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,7).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,8).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,9).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5)) sum(Hf(:,10).*Hf(:,5))/sum(Hf(:,5).*Hf(:,5))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,6);
plot([sum(Hf(:,1).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,2).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,3).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,4).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,5).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,6).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,7).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,8).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,9).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6)) sum(Hf(:,10).*Hf(:,6))/sum(Hf(:,6).*Hf(:,6))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,7);
plot([sum(Hf(:,1).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,2).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,3).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,4).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,5).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,6).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,7).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,8).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,9).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7)) sum(Hf(:,10).*Hf(:,7))/sum(Hf(:,7).*Hf(:,7))],'kx');
ylim([ymin1 ymax1]);
grid;
subplot(5,2,8);
plot([sum(Hf(:,1).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,2).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,3).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,4).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,5).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,6).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,7).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,8).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,9).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8)) sum(Hf(:,10).*Hf(:,8))/sum(Hf(:,8).*Hf(:,8))],'kx');
ylim([ymin2 ymax2]);
xlim([1 10]);
grid;
subplot(5,2,9);
plot([sum(Hf(:,1).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,2).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,3).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,4).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,5).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,6).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,7).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,8).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,9).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9)) sum(Hf(:,10).*Hf(:,9))/sum(Hf(:,9).*Hf(:,9))],'kx');
ylim([ymin2 ymax2]);
xlim([1 10]);
xlabel('Condition (1-10)');
ylabel('Projection');
grid;
subplot(5,2,10);
plot([sum(Hf(:,1).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,2).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,3).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,4).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,5).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,6).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,7).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,8).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,9).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10)) sum(Hf(:,10).*Hf(:,10))/sum(Hf(:,10).*Hf(:,10))],'kx');
ylim([ymin1 ymax1]);
grid;

% Continue with statistical modeling
disp('Press any key to continue:');
pause;

% Location algorithm using dot product
M=diag([m m m m m m m m m]);
SOk=100;     % boundary condition springs
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Generate frequency response function
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*(1-0.1*randn(9));
end
Hf(:,1)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

for kk=2:300,
    
% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Generate frequency response function
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*(1-0.1*randn(9));
end
Hf(:,kk)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

end

figure(3);
subplot(121);
[N1,X1]=hist(sum(Hf(:,2:300))/sum(Hf(:,1)),20);
plot(X1,N1/299,'k');
axis([-3 3 0 0.14]);
xlabel('Feature');
ylabel('p(Feature)');
subplot(122);
[N,X]=hist((sum(Hf(:,2:300))/sum(Hf(:,1))-mean((sum(Hf(:,2:300)))/sum(Hf(:,1))))/sqrt(var((sum(Hf(:,2:300))/sum(Hf(:,1))-1))),20);
plot(X,N/299,'k');
axis([-3 3 0 0.14]);
xlabel('(Feature-\mu)/\sigma');
ylabel('p((Feature-\mu)/\sigma)');

% Location algorithm using dot product
M=diag([m m m m m m m m m]);
SOk=100;     % boundary condition springs
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Generate frequency response function
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*(1-0.1*randn(9));
end
Hfd(:,1)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

M=diag([m m m m-0.03*m m m m m m]);
C=a*M+b*K;  % Assume proportional viscous damping model

for kk=2:300,
    
% Reset the state of random number generator
randn('state',rand*sum(100*clock));

% Generate frequency response function
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C).*(1-0.1*randn(9));
end
Hfd(:,kk)=[sum(abs(H(1,1,1:500))) sum(abs(H(1,1,1+500:500*2))) sum(abs(H(1,1,1+500*2:500*3))) sum(abs(H(1,1,1+500*3:500*4))) sum(abs(H(1,1,1+500*4:500*5)))]';

end

figure(4); 
[N2,X2]=hist(sum(Hfd(:,2:300))/sum(Hfd(:,1)),20);
plot(X2,N2/299,'k',X1,N1/299,'k:');
%axis([-3 3 0 0.14]);
ylim([0 0.14]);
xlim([.75 1.1])
xlabel('Feature');
ylabel('p(Feature)');

% Compute statistics of healthy and unhealthy features
mu2=mean(sum(Hfd(:,2:300))/sum(Hfd(:,1)));
mu1=mean(sum(Hf(:,2:300))/sum(Hf(:,1)));
sigma2=sqrt(var(sum(Hfd(:,2:300))/sum(Hfd(:,1))));
sigma1=sqrt(var(sum(Hf(:,2:300))/sum(Hf(:,1))));