% Lumped parameter nine degree of freedom plate model
% spatial analysis
% May 13, 2006
% 2006 Copyright D. E. Adams

clear all;
close all;

% Define parameters and model matrices
k=1e7;
m=0.2;
M=diag([m m m m m m m m m]);
SOk=100;     % boundary condition springs
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Generate frequency response function
Nf=5000; Ff=5000; % Number of frequency lines and frequency bandwidth
H=zeros(9,9,Nf);
f=linspace(0,Ff,Nf); % Generate frequency vector
a=.001; b=.00001; % Define coefficients for proportional damping model
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C);
end

% Frequencies at spectral line 75, 1705
figure(1);
subplot(211);
semilogy(f,abs(squeeze(H(:,1,:))),'k');
xlabel('Frequency [Hz]');
ylabel('Mag(H_{p1}(f) [m/N])');
ylim([1e-10 1e-3]);

shps(:,1)=imag(squeeze(H(:,1,75)))/max(abs(imag(squeeze(H(:,1,75)))));
shps(:,2)=imag(squeeze(H(:,1,1705)))/max(abs(imag(squeeze(H(:,1,1705)))));

subplot(223);
md=1; % Mode number to consider
plot3([0 1 2]',[0 0 0]',shps(1:3,md),'k-o'); hold on;
plot3([0 1 2]',[1 1 1]',shps(4:6,md),'k-o');
plot3([0 1 2]',[2 2 2]',shps(7:9,md),'k-o');
plot3([0 0 0]',[0 1 2]',shps([1 4 7],md),'k-o');
plot3([1 1 1]',[0 1 2]',shps([2 5 8],md),'k-o');
plot3([2 2 2]',[0 1 2]',shps([3 6 9],md),'k-o');
plot3([0 1 2]',[0 0 0]',0*shps(1:3,md),'k:'); hold on;
plot3([0 1 2]',[1 1 1]',0*shps(4:6,md),'k:');
plot3([0 1 2]',[2 2 2]',0*shps(7:9,md),'k:');
plot3([0 0 0]',[0 1 2]',0*shps([1 4 7],md),'k:');
plot3([1 1 1]',[0 1 2]',0*shps([2 5 8],md),'k:');
plot3([2 2 2]',[0 1 2]',0*shps([3 6 9],md),'k:');
axis([0 2 0 2 -3 3]);
view(-36.5,6);
xlabel('X');
ylabel('Y');
zlabel('Modal deflection');
subplot(224);
md=2; % Mode number to consider
plot3([0 1 2]',[0 0 0]',shps(1:3,md),'k-o'); hold on;
plot3([0 1 2]',[1 1 1]',shps(4:6,md),'k-o');
plot3([0 1 2]',[2 2 2]',shps(7:9,md),'k-o');
plot3([0 0 0]',[0 1 2]',shps([1 4 7],md),'k-o');
plot3([1 1 1]',[0 1 2]',shps([2 5 8],md),'k-o');
plot3([2 2 2]',[0 1 2]',shps([3 6 9],md),'k-o');
plot3([0 1 2]',[0 0 0]',0*shps(1:3,md),'k:'); hold on;
plot3([0 1 2]',[1 1 1]',0*shps(4:6,md),'k:');
plot3([0 1 2]',[2 2 2]',0*shps(7:9,md),'k:');
plot3([0 0 0]',[0 1 2]',0*shps([1 4 7],md),'k:');
plot3([1 1 1]',[0 1 2]',0*shps([2 5 8],md),'k:');
plot3([2 2 2]',[0 1 2]',0*shps([3 6 9],md),'k:');
axis([0 2 0 2 -3 3]);
view(-36.5,6);
xlabel('X');
ylabel('Y');
zlabel('Modal deflection');

% Define parameters and model matrices (damaged panel)
k=1e7;
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k-k/5 -k+k/5  0 -k -k  0;
   -k -k -k -k+k/5 8*k-k/5 -k -k -k -k;
   0  -k -k  0 -k 5*k  0 -k -k;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k  0 -k 3*k+k/SOk];

% Generate frequency response function
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C);
end

shpsd(:,1)=imag(squeeze(H(:,1,75)))/max(abs(imag(squeeze(H(:,1,75)))));
shpsd(:,2)=imag(squeeze(H(:,1,1701)))/max(abs(imag(squeeze(H(:,1,1701)))));

figure(2);
subplot(221);
md=1; % Mode number to consider
plot3([0 1 2]',[0 0 0]',shps(1:3,md)-shpsd(1:3,md),'k-o'); hold on;
plot3([0 1 2]',[1 1 1]',shps(4:6,md)-shpsd(4:6,md),'k-o');
plot3([0 1 2]',[2 2 2]',shps(7:9,md)-shpsd(7:9,md),'k-o');
plot3([0 0 0]',[0 1 2]',shps([1 4 7],md)-shpsd([1 4 7],md),'k-o');
plot3([1 1 1]',[0 1 2]',shps([2 5 8],md)-shpsd([2 5 8],md),'k-o');
plot3([2 2 2]',[0 1 2]',shps([3 6 9],md)-shpsd([3 6 9],md),'k-o');
plot3([0 1 2]',[0 0 0]',0*shps(1:3,md),'k:'); hold on;
plot3([0 1 2]',[1 1 1]',0*shps(4:6,md),'k:');
plot3([0 1 2]',[2 2 2]',0*shps(7:9,md),'k:');
plot3([0 0 0]',[0 1 2]',0*shps([1 4 7],md),'k:');
plot3([1 1 1]',[0 1 2]',0*shps([2 5 8],md),'k:');
plot3([2 2 2]',[0 1 2]',0*shps([3 6 9],md),'k:');
axis([0 2 0 2 -.01 .01]);
view(-36.5,25);
xlabel('X');
ylabel('Y');
zlabel('Change in deflection');
subplot(222);
md=2; % Mode number to consider
plot3([0 1 2]',[0 0 0]',shps(1:3,md)-shpsd(1:3,md),'k-o'); hold on;
plot3([0 1 2]',[1 1 1]',shps(4:6,md)-shpsd(4:6,md),'k-o');
plot3([0 1 2]',[2 2 2]',shps(7:9,md)-shpsd(7:9,md),'k-o');
plot3([0 0 0]',[0 1 2]',shps([1 4 7],md)-shpsd([1 4 7],md),'k-o');
plot3([1 1 1]',[0 1 2]',shps([2 5 8],md)-shpsd([2 5 8],md),'k-o');
plot3([2 2 2]',[0 1 2]',shps([3 6 9],md)-shpsd([3 6 9],md),'k-o');
plot3([0 1 2]',[0 0 0]',0*shps(1:3,md),'k:'); hold on;
plot3([0 1 2]',[1 1 1]',0*shps(4:6,md),'k:');
plot3([0 1 2]',[2 2 2]',0*shps(7:9,md),'k:');
plot3([0 0 0]',[0 1 2]',0*shps([1 4 7],md),'k:');
plot3([1 1 1]',[0 1 2]',0*shps([2 5 8],md),'k:');
plot3([2 2 2]',[0 1 2]',0*shps([3 6 9],md),'k:');
axis([0 2 0 2 -.1 .1]);
view(-36.5,25);
xlabel('X');
ylabel('Y');
zlabel('Change in deflection');

figure(3);
subplot(221);
plot(1:9,gradient(shps(:,1)),'k-',1:9,gradient(shpsd(:,1)),'k--');
% Uncomment this next line to obtain curvature instead of slope
%plot(1:9,del2(shps(:,1)),'k-',1:9,del2(shpsd(:,1)),'k--');
xlim([1 9]);
xlabel('DOF');
ylabel('Gradient');
%ylabel('Curvature');
subplot(222);
plot(1:9,gradient(shps(:,2)),'k-',1:9,gradient(shpsd(:,2)),'k--');
% Uncomment this next line to obtain curvature instead of slope
%plot(1:9,del2(shps(:,2)),'k-',1:9,del2(shpsd(:,2)),'k--');
xlim([1 9]);
xlabel('DOF');
ylabel('Gradient');
%ylabel('Curvature');

% Define parameters and model matrices (damaged panel)
k=1e7;
K=[3*k+k/SOk -k 0  -k -k  0  0  0  0;
   -k 5*k -k -k -k -k  0  0  0;
   0  -k 3*k+k/SOk 0  -k -k  0  0  0;
   -k -k 0  5*k -k  0 -k -k  0;
   -k -k -k -k 8*k -k -k -k -k;
   0  -k -k  0 -k 5*k-k/5  0 -k -k+k/5;
   0   0  0 -k -k  0 3*k+k/SOk -k  0;
   0   0  0 -k -k -k -k 5*k -k;
   0   0  0  0 -k -k+k/5  0 -k 3*k+k/SOk-k/5];

% Generate frequency response function
C=a*M+b*K;  % Assume proportional viscous damping model
for ii = 2:Nf,
    H(:,:,ii)=inv(K-M*(2*pi*f(ii))^2+j*(2*pi*f(ii))*C);
end

shpsd(:,1)=imag(squeeze(H(:,1,75)))/max(abs(imag(squeeze(H(:,1,75)))));
shpsd(:,2)=imag(squeeze(H(:,1,1691)))/max(abs(imag(squeeze(H(:,1,1691)))));

figure(2);
subplot(223);
md=1; % Mode number to consider
plot3([0 1 2]',[0 0 0]',shps(1:3,md)-shpsd(1:3,md),'k-o'); hold on;
plot3([0 1 2]',[1 1 1]',shps(4:6,md)-shpsd(4:6,md),'k-o');
plot3([0 1 2]',[2 2 2]',shps(7:9,md)-shpsd(7:9,md),'k-o');
plot3([0 0 0]',[0 1 2]',shps([1 4 7],md)-shpsd([1 4 7],md),'k-o');
plot3([1 1 1]',[0 1 2]',shps([2 5 8],md)-shpsd([2 5 8],md),'k-o');
plot3([2 2 2]',[0 1 2]',shps([3 6 9],md)-shpsd([3 6 9],md),'k-o');
plot3([0 1 2]',[0 0 0]',0*shps(1:3,md),'k:'); hold on;
plot3([0 1 2]',[1 1 1]',0*shps(4:6,md),'k:');
plot3([0 1 2]',[2 2 2]',0*shps(7:9,md),'k:');
plot3([0 0 0]',[0 1 2]',0*shps([1 4 7],md),'k:');
plot3([1 1 1]',[0 1 2]',0*shps([2 5 8],md),'k:');
plot3([2 2 2]',[0 1 2]',0*shps([3 6 9],md),'k:');
axis([0 2 0 2 -.01 .01]);
view(-36.5,25);
xlabel('X');
ylabel('Y');
zlabel('Change in deflection');
subplot(224);
md=2; % Mode number to consider
plot3([0 1 2]',[0 0 0]',shps(1:3,md)-shpsd(1:3,md),'k-o'); hold on;
plot3([0 1 2]',[1 1 1]',shps(4:6,md)-shpsd(4:6,md),'k-o');
plot3([0 1 2]',[2 2 2]',shps(7:9,md)-shpsd(7:9,md),'k-o');
plot3([0 0 0]',[0 1 2]',shps([1 4 7],md)-shpsd([1 4 7],md),'k-o');
plot3([1 1 1]',[0 1 2]',shps([2 5 8],md)-shpsd([2 5 8],md),'k-o');
plot3([2 2 2]',[0 1 2]',shps([3 6 9],md)-shpsd([3 6 9],md),'k-o');
plot3([0 1 2]',[0 0 0]',0*shps(1:3,md),'k:'); hold on;
plot3([0 1 2]',[1 1 1]',0*shps(4:6,md),'k:');
plot3([0 1 2]',[2 2 2]',0*shps(7:9,md),'k:');
plot3([0 0 0]',[0 1 2]',0*shps([1 4 7],md),'k:');
plot3([1 1 1]',[0 1 2]',0*shps([2 5 8],md),'k:');
plot3([2 2 2]',[0 1 2]',0*shps([3 6 9],md),'k:');
axis([0 2 0 2 -.1 .1]);
view(-36.5,25);
xlabel('X');
ylabel('Y');
zlabel('Change in deflection');

figure(3);
subplot(223);
plot(1:9,gradient(shps(:,1)),'k-',1:9,gradient(shpsd(:,1)),'k--');
% Uncomment this next line to obtain curvature instead of slope
%plot(1:9,del2(shps(:,1)),'k-',1:9,del2(shpsd(:,1)),'k--');
xlim([1 9]);
xlabel('DOF');
ylabel('Gradient');
%ylabel('Curvature');
subplot(224);
plot(1:9,gradient(shps(:,2)),'k-',1:9,gradient(shpsd(:,2)),'k--');
% Uncomment this next line to obtain curvature instead of slope
%plot(1:9,del2(shps(:,2)),'k-',1:9,del2(shpsd(:,2)),'k--');
xlim([1 9]);
xlabel('DOF');
ylabel('Gradient');
%ylabel('Curvature');