% One degree of freedom model
% Sensitivity analysis
% 4/7/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m=1;
k=10;
c=.1;

% Construct frequency vector in rad/sec
w=(0:.01:20)';

% Invert the impedance function at each frequency
for ii=1:max(size(w)),
    H(ii)=inv(-w(ii)^2*m+j*w(ii)*c+k);
end

% Compute sensitivity function
SHK=-H.^2;

% Decrease the stiffness
K=k-.01*k;

% Invert the impedance function at each frequency
for ii=1:max(size(w)),
    H2(ii)=inv(-w(ii)^2*m+j*w(ii)*c+K);
end

% Decrease the stiffness
K=k+.01*k;

% Invert the impedance function at each frequency
for ii=1:max(size(w)),
    H3(ii)=inv(-w(ii)^2*m+j*w(ii)*c+K);
end

figure(1);
subplot(211);
semilogy(w/2/pi,abs(squeeze(H)),'k-',w/2/pi,abs(squeeze(H2)),'k--',w/2/pi,abs(squeeze(H3)),'k:');
xlabel('Frequency [Hz]');
ylabel('Mag. H(\omega) [m/N]');
xlim([0 1]);
ylim([1e-2 1e1]);
subplot(212);
plot(w/2/pi,180/pi*angle(squeeze(H)),'k-',w/2/pi,180/pi*angle(squeeze(H2)),'k--',w/2/pi,180/pi*angle(squeeze(H3)),'k:');
xlabel('Frequency [Hz]');
ylabel('Phs. H(\omega) [deg]');
xlim([0 1]);
ylim([-180 10]);

% Continue on with sensitivity function
disp('Press any button to continue');
pause;

figure(2);
subplot(211);
semilogy(w/2/pi,abs(squeeze(SHK)),'k-');
xlabel('Frequency [Hz]');
ylabel('Mag. S_{H,K} (\omega) [(m/N)/(N/m)]');
xlim([0 1]);
ylim([1e-3 1e2]);
subplot(212);
plot(w/2/pi,180/pi*unwrap(angle(squeeze(SHK))),'k-');
xlabel('Frequency [Hz]');
ylabel('Phs. S_{H,K} (\omega) [deg]');
xlim([0 1]);

% Continue on with estimation of delta K
disp('Press any button to continue');
pause;

% Decrease the stiffness
K=k-.01*k;

% Invert the impedance function at each frequency
for ii=1:max(size(w)),
    H4(ii)=inv(-w(ii)^2*m+j*w(ii)*c+K);
end

% Decrease the stiffness
K=k-.02*k;

% Invert the impedance function at each frequency
for ii=1:max(size(w)),
    H5(ii)=inv(-w(ii)^2*m+j*w(ii)*c+K);
end

% Decrease the stiffness
K=k-.05*k;

% Invert the impedance function at each frequency
for ii=1:max(size(w)),
    H6(ii)=inv(-w(ii)^2*m+j*w(ii)*c+K);
end

figure(3);
subplot(211);
semilogy(w/2/pi,abs(squeeze(H)),'k-',w/2/pi,abs(squeeze(H4)),'k--',w/2/pi,abs(squeeze(H5)),'k:',w/2/pi,abs(squeeze(H6)),'k-.');
xlabel('Frequency [Hz]');
ylabel('Mag. H(\omega) [m/N]');
xlim([0 1]);
ylim([1e-2 1e1]);
subplot(212);
plot(w/2/pi,abs(squeeze(H4-H)./SHK),'k--',w/2/pi,abs(squeeze(H5-H)./SHK),'k:',w/2/pi,abs(squeeze(H6-H)./SHK),'k-.');
xlabel('Frequency [Hz]');
ylabel('Mag. \Delta K [N/m]');
xlim([0 1]);
ylim([0 1.5]);