% Demo of two-dimensional finite element model
% subject to sinusoidal pulse
% 7/12/06 
% 2006 Copyright D. E. Adams

clear all
close all

% Define parameters
Lx=1; % plate length in x
Ly=1; % plate length in y
p0=1.2; % air density
Pi0=1; % pressure
E0=7.1e10; % modulus
ps0=2.7e3; %  structure density
pos=0.33; % Poisson's ratio
h0=0.001; % thickness
f0=-2*Pi0; % distributed load

w=2*pi*1000; % excitation frequency
c=340; % sound speed
k=w/c; % wave number

NELEMX=10;NELEMY=10;% element number in x and y direction
NPE=4; % number of nodes of one element 
NELEM=NELEMX*NELEMY; %total number of elements
xx=0:Lx/NELEMX:Lx; 
x=[0:Lx/NELEMX:Lx];
y=zeros(1, NELEMX+1); 
for ii=1:NELEMY
    x=[x xx];% node coordinate
    y=[y Ly/NELEMY*ii*ones(1,NELEMX+1)];% node coordinate
end

ELEMCON=[];h=[];f=[];E=[];ps=[];
for ii=1:NELEMX
    for jj=1:NELEMY
        ELEMCON=[ELEMCON;(NELEMX+1)*(jj-1)+ii (NELEMX+1)*(jj-1)+ii+1 (NELEMX+1)*jj+ii+1 (NELEMX+1)*jj+ii]; %element connectivity
        h=[h h0]; % define element property
        E=[E E0];
        ps=[ps ps0];
        f=[f f0]; % define load 
    end
end

% Define flexural rigidity
D=E.*h.^3/(12*(1-pos^2));

NNODE=max(max(ELEMCON)); % number of nodes

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[K,M,F]=plate_matrix_assembly(ELEMCON,D,f,ps,h,x,y,NELEM,NPE,pos);% global stiffness and mass matrix and F vector without boundary condition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Generate damping matrix and state space matrices
alpha=0e-10;
beta=0e-10;
C=alpha*M+beta*K;
A=[zeros(max(size(K))) eye(max(size(K)));-inv(M)*K -inv(M)*C];
B=[zeros(1, max(size(K))) 1 zeros(1, max(size(K))-1)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(max(size(K))) zeros(max(size(K)))],zeros(max(size(K)),1));

% Simulate response
Nt=2048;
dt=.0004;
u=zeros(Nt,1);
u(1:64)=100*hanning(64).*sin(linspace(0,6*pi,64))';
t=(0:dt:(Nt-1)*dt)';
[xb,t]=lsim(sys,u,t);

% Impose damage on the modulus or thickness
%h(55)=h(55)/2;
E(55)=E(55)/2;

% Define flexural rigidity
D=E.*h.^3/(12*(1-pos^2));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[K,M,F]=plate_matrix_assembly(ELEMCON,D,f,ps,h,x,y,NELEM,NPE,pos);% global stiffness and mass matrix and F vector without boundary condition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Generate damping matrix and state space matrices
alpha=0e-10;
beta=0e-10;
C=alpha*M+beta*K;
A=[zeros(max(size(K))) eye(max(size(K)));-inv(M)*K -inv(M)*C];
B=[zeros(1, max(size(K))) 1 zeros(1, max(size(K))-1)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(max(size(K))) zeros(max(size(K)))],zeros(max(size(K)),1));

% Simulate response
[x,t]=lsim(sys,u,t);

x=x*1e4;
xb=xb*1e4;

% Plot the results
figure(1);
subplot(11,11,1);
kk=1; subplot(11,11,kk); axis([0 .04 -1e-1 1e-1]);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=2; subplot(11,11,kk); axis([0 .04 -1e-1 1e-1]);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=3; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=4; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=5; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=6; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=7; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=8; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=9; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=10; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=11; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=12; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=13; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=14; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=15; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=16; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=17; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=18; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=19; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=20; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=21; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=22; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=23; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=24; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=25; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=26; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=27; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=28; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=29; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=30; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=31; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=32; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=33; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=34; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=35; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=36; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=37; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=38; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=39; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=40; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=41; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=42; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=43; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=44; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=45; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=46; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=47; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=48; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=49; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=50; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=51; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=52; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=53; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=54; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=55; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=56; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=57; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=58; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=59; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=60; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=61; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=62; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=63; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=64; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=65; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=66; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=67; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=68; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=69; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=70; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=71; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=72; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=73; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=74; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=75; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=76; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=77; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=78; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=79; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=80; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=81; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=82; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=83; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=84; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=85; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=86; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=87; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=88; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=89; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=90; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=91; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=92; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=93; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=94; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=95; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=96; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=97; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=98; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=99; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=100; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=101; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=102; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=103; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=104; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=105; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=106; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=107; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=108; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=109; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=110; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=111; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=112; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=113; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=114; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=115; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=116; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=117; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=118; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=119; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=120; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);
kk=121; subplot(11,11,kk);
plot(t,x(:,1+3*(kk-1))-xb(:,1+3*(kk-1)),'k'); axis([0 .04 -1e-1 1e-1]);

figure(2);
kk=1; subplot(2,2,1);
plot(t,abs(x(:,1+3*(kk-1))-1*xb(:,1+3*(kk-1))),'k',t,0*abs(xb(:,1+3*(kk-1)))/1e7,'k--'); axis([0 .014 -0e-1 5e-6]);
xlabel('Time [s]');
ylabel('\Delta x_1 * 1e-1 [m]');
kk=11; subplot(2,2,2);
plot(t,abs(x(:,1+3*(kk-1))-1*xb(:,1+3*(kk-1))),'k',t,0*abs(xb(:,1+3*(kk-1)))/1e1,'k--'); axis([0 .014 -0e-1 5e-6]);
xlabel('Time [s]');
ylabel('\Delta x_{11} * 1e-1 [m]');
kk=111; subplot(2,2,3);
plot(t,abs(x(:,1+3*(kk-1))-1*xb(:,1+3*(kk-1))),'k',t,0*abs(xb(:,1+3*(kk-1)))/1e3,'k--'); axis([0 .014 -0e-1 5e-6]);
xlabel('Time [s]');
ylabel('\Delta x_{111} * 1e-1 [m]');
kk=121; subplot(2,2,4);
plot(t,abs(x(:,1+3*(kk-1))-1*xb(:,1+3*(kk-1))),'k',t,0*abs(xb(:,1+3*(kk-1)))/1e3,'k--'); axis([0 .014 -0e-1 5e-6]);
xlabel('Time [s]');
ylabel('\Delta x_{121} * 1e-1 [m]');