% One dimensional rod
% Transverse wave propagation
% 4/14/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
Ne=17*2;
E=70e9;
b=2.54e-2;
h=2.54e-2/10;
Ae=b*h;
Ie=b*h^3/12;
L=0.1*10;       % Length of component
Le=L/(Ne-1);   % Length of each element  
V=Ae*L;
rho=2700*V/L;  % Density per unit length
Ks=0.6*E*Ie/Le^3;

% Generate matrices
m=rho*Le/420*[156 22*Le 54 -13*Le; 22*Le 4*Le^2 13*Le -3*Le^2; 54 13*Le 156 -22*Le; -13*Le -3*Le^2 -22*Le 4*Le^2];
k=E*Ie/Le^3*[12 6*Le -12 6*Le; 6*Le 4*Le^2 -6*Le 2*Le^2; -12 -6*Le 12 -6*Le; 6*Le 2*Le^2 -6*Le 4*Le^2];

% Generate total mass and stiffness matrices
M=zeros(Ne*2);
K=zeros(Ne*2);
for ii = 1:2:2*Ne-3,
    M(ii:ii+3,ii:ii+3)=M(ii:ii+3,ii:ii+3)+m;
    K(ii:ii+3,ii:ii+3)=K(ii:ii+3,ii:ii+3)+k;
end

% Apply the boundary conditions
K(1,1)=K(1,1)+Ks;
K(2*Ne-1,2*Ne-1)=K(2*Ne-1,2*Ne-1)+Ks;

% Generate damping matrix and state space matrices
alpha=0e-8;
beta=0e-8;
C=alpha*M+beta*K;
A=[zeros(2*Ne) eye(2*Ne);-inv(M)*K -inv(M)*C];
B=[zeros(1,2*Ne) 1 zeros(1,2*Ne-1)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(2*Ne) zeros(2*Ne)],zeros(2*Ne,1));

% Simulate response
Nt=1024;
dt=5e-6;
xmax=2e-3;
ymax=8e-4;
t=(0:dt:(Nt-1)*dt)';
f1=zeros(Nt,1);
f1(1:200)=1e6*hanning(200).*sin(linspace(0,8*pi,200))';
[x,t]=lsim(sys,f1,t);

% Plot force
plot((0:1/t(Nt):(Nt-1)/t(Nt)),abs(fft(f1)/Nt/2),'k-');
ylabel('F_{1}(\omega) [N]')
xlabel('Frequency [Hz]');
xlim([0 4e4]);

% Plot response
figure(2);
subplot(611);
plot(t,f1(:,1),'k');
ylabel('f_{1} [N]')
xlim([0 xmax]);
subplot(612);
plot(t,x(:,1),'k');
ylabel('x_{1} [m]');
xlim([0 xmax]);
ylim([-ymax ymax]);
subplot(613);
plot(t,x(:,7),'k');
ylabel('x_{4} [m]');
xlim([0 xmax]);
ylim([-ymax ymax]);
subplot(614);
plot(t,x(:,15),'k');
ylabel('x_{8} [m]');
xlim([0 xmax]);
ylim([-ymax ymax]);
subplot(615);
plot(t,x(:,23),'k');
ylabel('x_{12} [m]');
xlim([0 xmax]);
ylim([-ymax ymax]);
subplot(616);
plot(t,x(:,31),'k');
xlabel('Time [sec]');
ylabel('x_{16} [m]');
xlim([0 xmax]);
ylim([-ymax ymax]);