% One dimensional rod
% temporal analysis
% 6/18/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
Ne=17;
A=(2.54e-2)^2;
E=70e9;
L=0.1;     % Length of component
Le=L/Ne;   % Length of each element  
V=A*L;
rho=2700*V/L;  % Density per unit length
Ks=0.01*A*E/Le;

% Generate matrices
m=[rho*Le/3 rho*Le/6;rho*Le/6 rho*Le/3];
k=[A*E/Le -A*E/Le; -A*E/Le A*E/Le];

% Generate total mass and stiffness matrices
M=zeros(Ne+1);
K=zeros(Ne+1);
for ii = 1:Ne,
    M(ii:ii+1,ii:ii+1)=M(ii:ii+1,ii:ii+1)+m;
    K(ii:ii+1,ii:ii+1)=K(ii:ii+1,ii:ii+1)+k;
end

% Apply the boundary conditions
K(1,1)=K(1,1)+Ks;
K(Ne+1,Ne+1)=K(Ne+1,Ne+1)+Ks;

% Generate damping matrix and state space matrices
alpha=0e-15;
beta=0e-15;
C=alpha*M+beta*K;
A=[zeros(Ne+1) eye(Ne+1);-inv(M)*K -inv(M)*C];
B=[zeros(1,Ne+1) 1 zeros(1,Ne)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(Ne+1) zeros(Ne+1)],zeros(Ne+1,1));

% Simulate response
Nt=1024;
dt=2e-7;
xmax=.00004;
ymax=5e-7;
t=(0:dt:(Nt-1)*dt)';
f1=zeros(Nt,1);
f1(1:100)=1e6*hanning(100).*sin(linspace(0,6*pi,100))';
[x,t]=lsim(sys,f1,t);

% Insert the crack
crackind=8;
K(crackind:crackind+1,crackind:crackind+1)=K(crackind:crackind+1,crackind:crackind+1)-0.1*k;

% Generate damping matrix and state space matrices
C=alpha*M+beta*K;
A=[zeros(Ne+1) eye(Ne+1);-inv(M)*K -inv(M)*C];
B=[zeros(1,Ne+1) 1 zeros(1,Ne)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(Ne+1) zeros(Ne+1)],zeros(Ne+1,1));

% Simulate response
[xd,t]=lsim(sys,f1,t);

% Compute parameters and functions with and without damage
x=x(1:150,:);
xd=xd(1:150,:);
t=t(1:150);

mu1=mean(x);
mu2=mean(xd);
rmsd=sqrt(mean((x-xd).^2));
R12=mean(x.*xd);
C12=mean((x-ones(150,1)*mu1).*(xd-ones(150,1)*mu2));
mut1=mean((t*ones(1,18)).*(x.^2));
mut2=mean((t*ones(1,18)).*(xd.^2));
vart1=mean(((t*ones(1,18)-ones(150,1)*mut1).^2).*(x.^2));
vart2=mean(((t*ones(1,18)-ones(150,1)*mut2).^2).*(xd.^2));
a1(:,1)=xcorr(x(:,8),x(:,8));
ad(:,1)=xcorr(xd(:,8),xd(:,8));
cc(:,1)=xcorr(x(:,1),x(:,18));
cc(:,2)=xcorr(x(:,1),xd(:,18));

% Plot results
figure(1);
subplot(411);
plot(1:18,mut1,'ko-',1:18,mut2,'kx--');
ylabel('\mu_t');
xlabel('Sensor location');
axis([1 12 4e-19 12e-19]);
subplot(412);
plot(1:18,vart1,'ko-',1:18,vart2,'kx--');
ylabel('\sigma_t');
xlabel('Sensor location');
axis([1 12 0 3e-23]);
subplot(413);
plot((-149:1:149)',a1(:,1),'k-',(-149:1:149)',ad(:,1),'k--');
ylabel('R_{11}(n)');
xlabel('n');
subplot(414);
plot((-149:1:149)',cc(:,1),'k-',(-149:1:149)',cc(:,2),'k--');
ylabel('C_{12}(n)');
xlabel('n');