% Observer demo with thermal model of panel
% 6/14/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Establish parameters
Ar=18*0.0254;
Lg=.01;
L1=.005;
L2=.02;
V1=Ar*L1;
V2=Ar*L2;
Va=3*(V1+V2); % Assume airframe capacitance is >> panel capacitance
kg=50e-3; % W/m-deg K
k1=20;    % W/m-deg C
k2=2;     % Assume honeycomb reduces conductivity by factor of 10
h=150;    % W/m^2-deg K
Rg=Lg/kg/Ar;
R1=L1/k1/Ar;
R2=L2/k2/Ar;
Rconv=1/h/Ar;
b=(2/R1)/(1/Rconv+2/R1);
a=(1/Rconv)/(1/Rconv+2/R1);
spa=875;
sp1=500;
sp2=500;
rhoa=2770;
ca=rhoa*spa*Va;
rho1=8000;
rho2=rho1/10;
c1=rho1*sp1*V1;
c2=rho2*sp2*V2;

% Generate system matrices
A=[-1/Rg 2/Rg -2/Rg 2/Rg-b/Rg; 
    1/Rg -2/Rg-2/R1 2/Rg+2/R1+2/R1 -2/Rg+b/Rg-2/R1+b/R1-2/R1+b/R1; 
    0 2/R1 -2/R1-2/R1-2/R2 2/R1-b/R1+2/R1-b/R1+2/R2-b/R2+2/R2-b/R2; 
    0 0 2/R2 -2/R2+b/R2-2/R2+b/R2-b/Rconv];
A(1,:)=A(1,:)/ca;
A(2,:)=A(2,:)/c1;
A(3,:)=A(3,:)/c2;
A(4,:)=A(4,:)/c1;

% Generate system in MATLAB
sys=ss(A,[-a/ca/Rg a/c1/Rg+2*a/c1/R1 -2*a/c2/R1-2*a/c2/R2 2*a/c1/R2+(1-a)/c1/Rconv]',eye(4),zeros(4,1));

% Generate time vector and input temperature vector
u=[20:1:1000 1000:-1:20 20*ones(1,2000)];
t=(0:1:max(size(u))-1)';

% Simulate response
y=lsim(sys,u,t,[20 20 20 20]);

% Plot results
figure(1);
subplot(211);
plot(t,u,'k-');
xlabel('Time [sec]');
ylabel('T_o(t) [deg C]');
axis([0 3500 0 1000]);
subplot(212);
plot(t,y(:,1),'k-',t,y(:,2),'k--',t,y(:,3),'k:',t,y(:,4),'k-.');
xlabel('Time [sec]');
ylabel('T_i [deg C]');
axis([0 3500 0 1000]);

% Continue to demonstrate observer
disp('Press any key to continue');
pause;

% Set observer gain matrix
K=[ones(1,4)/1e3]';

% Construct combined observer and system
sysc=ss([A-K*[1 0 0 0] K*[1 0 0 0]; zeros(4,4) A],[-a/ca/Rg a/c1/Rg+2*a/c1/R1 -2*a/c2/R1-2*a/c2/R2 2*a/c1/R2+(1-a)/c1/Rconv -a/ca/Rg a/c1/Rg+2*a/c1/R1 -2*a/c2/R1-2*a/c2/R2 2*a/c1/R2+(1-a)/c1/Rconv]',eye(8),zeros(8,1));

% Simulate combined observer and system
yc=lsim(sysc,u,t,[0 0 0 0 20 20 20 20]);

% Plot results
figure(2);
subplot(411);
plot(t,yc(:,1),'k-',t,yc(:,5),'k--');
ylabel('T_a [deg C]');
axis([0 3500 0 50]);
subplot(412);
plot(t,yc(:,2),'k-',t,yc(:,6),'k--');
ylabel('T_{12} [deg C]');
axis([0 3500 0 800]);
subplot(413);
plot(t,yc(:,3),'k-',t,yc(:,7),'k--');
ylabel('T_{23} [deg C]');
axis([0 3500 0 800]);
subplot(414);
plot(t,yc(:,4),'k-',t,yc(:,8),'k--');
ylabel('T_{34} [deg C]');
xlabel('Time [sec]');
axis([0 3500 0 800]);