% Three degree of freedom model
% Sensitivity analysis
% 4/7/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.02*M+.02*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

% Compute the sensitivity function
SHK=-squeeze(H(2,2,:)-H(3,2,:)).^2;

k3=k3+.08*k3;

K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.02*M+.02*K;

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H2(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(1);
subplot(211);
semilogy(w/2/pi,abs(squeeze(H(2,2,:))),'k-',w/2/pi,abs(squeeze(H2(2,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{22} [m/N]');
xlim([0 3]);
ylim([1e-3 1e1]);
subplot(212);
plot(w/2/pi,abs(squeeze(H2(2,2,:)-H(2,2,:))./SHK),'k-');
xlabel('Frequency [Hz]');
ylabel('Mag. \Delta K [N/m]');
xlim([0 3]);
ylim([0 1]);