% Three degree of freedom model
% Estimate external loads
% 4/4/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.04*M+.04*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

% Generate negative frequency content of frequency response functions
for ii=1:max(size(w))-2,
    H(1:3,1:3,ii+max(size(w)))=conj(H(1:3,1:3,max(size(w))-ii));
end

% Apply impact load
T=1/(w(2)/2/pi);
t=linspace(0,T,max(size(H)));
f2=zeros(max(size(t)),1);
f2(1:10)=sin(2*pi/t(20)*t(1:10));
F2=fft(f2)/(max(size(t))/2);

figure(1);
subplot(211);
plot(t,f2,'k-');
xlabel('Time [sec]');
ylabel('Force f_2(t) [N]');
axis([0 40 -.1 1]);
subplot(212);
plot(w,abs(F2(1:max(size(w)))),'k-');
xlabel('Frequency [rad/s]');
ylabel('Mag. F_2(\omega) [N]');
axis([0 10 0 0.02]);

% Calculate response in frequency domain
for ii=1:max(size(H)),
    X(1:3,ii)=H(1:3,1:3,ii)*[0; F2(ii); 0];
end

% Plot frequency domain spectra
figure(2);
subplot(212);
plot(w,abs(X(1,1:max(size(w)))),'k-',w,abs(X(2,1:max(size(w)))),'k--',w,abs(X(3,1:max(size(w)))),'k:');
xlabel('Frequency [rad/s]');
ylabel('Mag. X_1(\omega), X_2(\omega), X_3(\omega) [m]');
axis([0 10 0 0.008]);

% Calculate response in time domain
x(:,1)=real(ifft(X(1,:)))'*max(size(t))/2;
x(:,2)=real(ifft(X(2,:)))'*max(size(t))/2;
x(:,3)=real(ifft(X(3,:)))'*max(size(t))/2;

figure(2);
subplot(211);
plot(t,x(:,1),'k-',t,x(:,2),'k--',t,x(:,3),'k:');
xlabel('Time [sec]');
ylabel('Response x_1, x_2, x_3 [m]');
axis([0 40 -1.5e-1 1.5e-1]);

% Estimate excitation force (inverse problem)
for ii=1:max(size(H)),
    Fe(1:3,ii)=inv(H(1:3,1:3,ii))*X(1:3,ii);
end