% Three degree of freedom model
% Modal modeling and parameter estimation
% 4/8/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.02*M+.02*K;

% Construct frequency vector in rad/sec
w=(0:.02:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

% Plot imaginary parts
figure(1);
plot(w/2/pi,imag(squeeze(H(1,2,:))),'k',w/2/pi,imag(squeeze(H(2,2,:))),'k--',w/2/pi,imag(squeeze(H(3,2,:))),'k:');
xlabel('Frequency [Hz]');
ylabel('Imag. H_{p2} [m/N]');
xlim([0 1.5]);
ylim([-1.5 0.2]);

% Extract mode shapes using peak-pick method
fr=2*pi*[.39 .68 .96];  % Damped natural frequencies in rad/s
imag(H(:,2,round(fr(1)/w(2))))/max(abs(imag(H(:,2,round(fr(1)/w(2))))))
imag(H(:,2,round(fr(2)/w(2))))/max(abs(imag(H(:,2,round(fr(2)/w(2))))))
imag(H(:,2,round(fr(3)/w(2))))/max(abs(imag(H(:,2,round(fr(3)/w(2))))))

% Continue on with global least-squares FRF method
disp('Press any button to continue');
pause;

fri=round(2*pi*[.39 .68 .96]/w(2));

% Mode #1
for ii=1:6,
    D1(1+3*(ii-1):3+3*(ii-1),1:4)=[squeeze(H(1:3,2,fri(1)-4+ii)) eye(3)];
    D2(1+3*(ii-1):3+3*(ii-1),1)=[j*w(fri(1)-4+ii)*squeeze(H(1:3,2,fri(1)-4+ii))];
end
p=pinv(D1)*D2;
p(1)
p(2:4)/max(abs(p(2:4)))

% Mode #2
for ii=1:6,
    D1(1+3*(ii-1):3+3*(ii-1),1:4)=[squeeze(H(1:3,2,fri(2)-4+ii)) eye(3)];
    D2(1+3*(ii-1):3+3*(ii-1),1)=[j*w(fri(2)-4+ii)*squeeze(H(1:3,2,fri(2)-4+ii))];
end
p=pinv(D1)*D2;
p(1)
p(2:4)/max(abs(p(2:4)))

% Mode #3
for ii=1:6,
    D1(1+3*(ii-1):3+3*(ii-1),1:4)=[squeeze(H(1:3,2,fri(3)-4+ii)) eye(3)];
    D2(1+3*(ii-1):3+3*(ii-1),1)=[j*w(fri(3)-4+ii)*squeeze(H(1:3,2,fri(3)-4+ii))];
end
p=pinv(D1)*D2;
p(1)
p(2:4)/max(abs(p(2:4)))