% Three degree of freedom model
% Transmissibility analysis
% 3/27/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.04*M+.04*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(1);
subplot(311);
plot(w/2/pi,abs(squeeze(H(2,2,:))./squeeze(H(1,2,:))),'k-');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{21} [m/m]');
xlim([0 3]);
ylim([0 20]);
subplot(312);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(2,2,:))),'k-');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{32} [m/m]');
xlim([0 3]);
ylim([0 4]);
subplot(313);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(1,2,:))),'k-');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{31} [m/m]');
xlim([0 3]);
ylim([0 2]);

% Continue on with variation in K2
disp('Press any button to continue');
pause;

figure(2);
subplot(311);
plot(w/2/pi,abs(squeeze(H(2,2,:))./squeeze(H(1,2,:))),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. T_{21} [m/m]');
xlim([0 3]);
ylim([0 20]);
subplot(312);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(2,2,:))),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. T_{32} [m/m]');
xlim([0 3]);
ylim([0 4]);
subplot(313);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(1,2,:))),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. T_{31} [m/m]');
xlim([0 3]);
ylim([0 2]);

% Parameters (damaged)
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12-12*0.25;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.04*M+.04*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(2);
subplot(311);
plot(w/2/pi,abs(squeeze(H(2,2,:))./squeeze(H(1,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{21} [m/m]');
xlim([0 3]);
ylim([0 20]);
subplot(312);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(2,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{32} [m/m]');
xlim([0 3]);
ylim([0 4]);
subplot(313);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(1,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{31} [m/m]');
xlim([0 3]);
ylim([0 2]);

% Continue on with variation in M3
disp('Press any button to continue');
pause;

% Parameters
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.04*M+.04*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(3);
subplot(311);
plot(w/2/pi,abs(squeeze(H(2,2,:))./squeeze(H(1,2,:))),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. T_{21} [m/m]');
xlim([0 3]);
ylim([0 20]);
subplot(312); 
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(2,2,:))),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. T_{32} [m/m]');
xlim([0 3]);
ylim([0 4]);
subplot(313);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(1,2,:))),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. T_{31} [m/m]');
xlim([0 3]);
ylim([0 2]);

% Parameters
m1=1;
m2=.9;
m3=1.1-1.1*0.25;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.04*M+.04*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(3);
subplot(311);
plot(w/2/pi,abs(squeeze(H(2,2,:))./squeeze(H(1,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{21} [m/m]');
xlim([0 3]);
ylim([0 20]);
subplot(312);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(2,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{32} [m/m]');
xlim([0 3]);
ylim([0 4]);
subplot(313);
plot(w/2/pi,abs(squeeze(H(3,2,:))./squeeze(H(1,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. T_{31} [m/m]');
xlim([0 3]);
ylim([0 2]);