% Three degree of freedom model
% Virtual force analysis
% 4/8/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=.9;
m3=1.1;
k1=10;
k2=12;
k3=8;
k4=10;

% Generate matrices
M=[m1 0 0;0 m2 0; 0 0 m3];
K=[k1+k2 -k2 0;-k2 k2+k3 -k3;0 -k3 k3+k4];
C=.02*M+.02*K;

% Construct frequency vector in rad/sec
w=(0:.05:20)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

m1=m1-.05*m1;

M=[m1 0 0;0 m2 0; 0 0 m3];
C=.02*M+.02*K;

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H2(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(1);
subplot(311);
semilogy(w/2/pi,abs(squeeze(H(1,2,:))),'k-',w/2/pi,abs(squeeze(H2(1,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{12} [m/N]');
xlim([0 3]);
ylim([1e-3 1e1]);
subplot(312);
semilogy(w/2/pi,abs(squeeze(H(2,2,:))),'k-',w/2/pi,abs(squeeze(H2(2,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{22} [m/N]');
xlim([0 3]);
ylim([1e-3 1e1]);
subplot(313);
semilogy(w/2/pi,abs(squeeze(H(3,2,:))),'k-',w/2/pi,abs(squeeze(H2(3,2,:))),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{32} [m/N]');
xlim([0 3]);
ylim([1e-3 1e1]);

% Calculate virtual force projection matrix
for ii=1:max(size(w)),
    Hv(1:3,1:3,ii)=inv(squeeze(H(1:3,1:3,ii)))*H2(1:3,1:3,ii)-eye(3);
end

figure(2);
semilogy(w/2/pi,abs(squeeze(Hv(1,2,:))),'k-',w/2/pi,abs(squeeze(Hv(2,2,:))),'k--',w/2/pi,abs(squeeze(Hv(3,2,:))),'k:');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{v}');
xlim([0 3]);
ylim([1e-20 1e1]);