% Time-frequency analysis
% 5/23/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Create time vector and frequency vector
Nt=2^14;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector
BS2=2048;

% Create linear chirp from 0 to 2.6 Hz
y=sin(2*pi*(0+0.02*t).*t);

% Plot chirp
figure(1);
subplot(211);
plot(t,y,'k-');
xlim([0 64]);
xlabel('Time [sec]');
ylabel('y(t)');

% Define P301 window function
ftv=linspace(-0.5,0.5,BS2)';
wind=0.9994484+2*(0.955728*cos(2*pi*1*ftv)+0.539289*cos(2*pi*2*ftv)+0.091581*cos(2*pi*3*ftv));
[S,fs,T]=specgram(y,BS2,Fs,wind,BS2/2);

% Shown spectrogram process
wind1=zeros(Nt,1);
wind1(1:BS2)=wind;
wind2=zeros(Nt,1);
wind2(3*BS2+1:4*BS2)=wind;
wind3=zeros(Nt,1);
wind3(5*BS2+1:6*BS2)=wind;
figure(1);
subplot(2,3,4);
plot(t,y.*wind1,'k-');
xlim([0 64]);
ylim([-4 4]);
xlabel('Time [sec]');
ylabel('y(t)');
subplot(2,3,5);
plot(t,y.*wind2,'k-');
xlim([0 64]);
ylim([-4 4]);
xlabel('Time [sec]');
ylabel('y(t)');
subplot(2,3,6);
plot(t,y.*wind3,'k-');
xlim([0 64]);
ylim([-4 4]);
xlabel('Time [sec]');
ylabel('y(t)');

% Compute spectrogram (DTFT)

% Define P301 window function
ftv=linspace(-0.5,0.5,BS2)';
wind=0.9994484+2*(0.955728*cos(2*pi*1*ftv)+0.539289*cos(2*pi*2*ftv)+0.091581*cos(2*pi*3*ftv));
[S,fs,T]=specgram(y,BS2,Fs,wind,BS2/2);

% Plot spectrogram
fmax=40;
figure(2);
subplot(121);
surf(T,fs(1:fmax),abs(S(1:fmax,:))/(BS2/2));
ylim([0 5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Frequency [Hz]');
zlabel('Magnitude Y(t,f)');
subplot(122);
surf(T,fs(1:fmax),abs(S(1:fmax,:))/(BS2/2));
ylim([0 5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(0,90);
xlabel('Time [sec]');
ylabel('Frequency [Hz]');
zlabel('Magnitude Y(t,f)');

% Continue on with wave propagation example
disp('Press any key to continue:');
pause;

% Parameters
Ne=17;
A=(2.54e-2)^2;
E=70e9;
L=0.1;     % Length of component
Le=L/Ne;   % Length of each element  
V=A*L;
rho=2700*V/L;  % Density per unit length
Ks=0.01*A*E/Le;

% Generate matrices
m=[rho*Le/3 rho*Le/6;rho*Le/6 rho*Le/3];
k=[A*E/Le -A*E/Le; -A*E/Le A*E/Le];

% Generate total mass and stiffness matrices
M=zeros(Ne+1);
K=zeros(Ne+1);
for ii = 1:Ne,
    M(ii:ii+1,ii:ii+1)=M(ii:ii+1,ii:ii+1)+m;
    K(ii:ii+1,ii:ii+1)=K(ii:ii+1,ii:ii+1)+k;
end

% Apply the boundary conditions
K(1,1)=K(1,1)+Ks;
K(Ne+1,Ne+1)=K(Ne+1,Ne+1)+Ks;

% Generate damping matrix and state space matrices
alpha=0e-15;
beta=0e-15;
C=alpha*M+beta*K;
A=[zeros(Ne+1) eye(Ne+1);-inv(M)*K -inv(M)*C];
B=[zeros(1,Ne+1) 1 zeros(1,Ne)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(Ne+1) zeros(Ne+1)],zeros(Ne+1,1));

% Simulate response
Nt=1024/2;
dt=2e-7;
xmax=.00004;
ymax=5e-7;
t=(0:dt:(Nt-1)*dt)';
f1=zeros(Nt,1);
f1(1:100)=1e6*hanning(100).*sin(linspace(0,6*pi,100))';
[x,t]=lsim(sys,f1,t);

% Insert the crack
crackind=8;
K(crackind:crackind+1,crackind:crackind+1)=K(crackind:crackind+1,crackind:crackind+1)-0.1*k;

% Generate damping matrix and state space matrices
C=alpha*M+beta*K;
A=[zeros(Ne+1) eye(Ne+1);-inv(M)*K -inv(M)*C];
B=[zeros(1,Ne+1) 1 zeros(1,Ne)]';

% Generate system in MATLAB
sys=ss(A,B,[eye(Ne+1) zeros(Ne+1)],zeros(Ne+1,1));

% Simulate response
[xd,t]=lsim(sys,f1,t);

% Compute spectrograms (DTFT)
BS=32;

% Plot results
figure(3);
fmax=17;
wind=ones(BS,1);
[Sb,Fs,T]=specgram(x(:,1),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,1),BS,1/dt,wind,BS/2);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 10e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

figure(4);
wind=ones(BS,1);
[Sb,Fs,T]=specgram(x(:,8),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,8),BS,1/dt,wind,BS/2);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 10e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

% Plot results
figure(5);
wind=hanning(BS);
[Sb,Fs,T]=specgram(x(:,1),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,1),BS,1/dt,wind,BS/2);
subplot(4,4,1);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,2),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,2),BS,1/dt,wind,BS/2);
subplot(4,4,2);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,3),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,3),BS,1/dt,wind,BS/2);
subplot(4,4,3);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,4),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,4),BS,1/dt,wind,BS/2);
subplot(4,4,4);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,5),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,5),BS,1/dt,wind,BS/2);
subplot(4,4,5);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,6),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,6),BS,1/dt,wind,BS/2);
subplot(4,4,6);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,7),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,7),BS,1/dt,wind,BS/2);
subplot(4,4,7);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,8),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,8),BS,1/dt,wind,BS/2);
subplot(4,4,8);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,9),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,9),BS,1/dt,wind,BS/2);
subplot(4,4,9);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,10),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,10),BS,1/dt,wind,BS/2);
subplot(4,4,10);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,11),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,11),BS,1/dt,wind,BS/2);
subplot(4,4,11);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,12),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,12),BS,1/dt,wind,BS/2);
subplot(4,4,12);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,13),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,13),BS,1/dt,wind,BS/2);
subplot(4,4,13);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,14),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,14),BS,1/dt,wind,BS/2);
subplot(4,4,14);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,15),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,15),BS,1/dt,wind,BS/2);
subplot(4,4,15);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

[Sb,Fs,T]=specgram(x(:,16),BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd(:,16),BS,1/dt,wind,BS/2);
subplot(4,4,16);
surf(T,Fs(1:fmax),(abs(Sb(1:fmax,:)-Sd(1:fmax,:))/(BS/2)));
ylim([0 5e5]);
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag');
view(0,90);

colormap('prism');

% Continue on with nonlinear stiffness example
disp('Press any key to continue:');
pause;

% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(2*(1+.005*t).*t)+1*sin(5*(1+.005*t).*t)+1*sin(8*(1+.005*t).*t)+1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xb1=x1;
xb2=x2;

mu2=80; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(2*(1+.005*t).*t)+1*sin(5*(1+.005*t).*t)+1*sin(8*(1+.005*t).*t)+1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xd1=x1;
xd2=x2;

% Define P301 window function
BS=8192;
ftv=linspace(-0.5,0.5,BS)';
wind=0.9994484+2*(0.955728*cos(2*pi*1*ftv)+0.539289*cos(2*pi*2*ftv)+0.091581*cos(2*pi*3*ftv));

% Compute spectrograms
[Sb,Fs,T]=specgram(xb2,BS,1/dt,wind,BS/2);
[Sd,Fs,T]=specgram(xd2,BS,1/dt,wind,BS/2);

% Plot results
fmax=160;
figure(6);
subplot(121);
surf(T,Fs(1:fmax),log10(abs(Sb(1:fmax,:))/(BS/2)));
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag Y(t,\omega)');
view(0,90);
subplot(122);
surf(T,Fs(1:fmax),log10(abs(Sd(1:fmax,:))/(BS/2)));
xlim([0 T(max(size(T)))]);
shading('interp');
view(-74.5,76);
xlabel('Time [sec]');
ylabel('Freq [Hz]');
zlabel('Mag Y(t,\omega)');
view(0,90);