% Two degree of freedom
% Spectral (DFT) analysis
% 5/18/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector
f=(0:1/t(Nt):(Nt-2)/t(Nt))';                    % Frequency vector

% Simulate restoring forces for joint damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(2*t)+1*sin(5*t)+1*sin(8*t)+1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

x1b=x1;
x2b=x2;

% Simulate damage with change in coupling stiffness
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20-20*0.10;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=sin(2*t)+sin(5*t)+sin(8*t)+1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

x1d=x1;
x2d=x2;

% Plot results
figure(1);
subplot(211);
plot(f,abs(fft(x1b))/(Nt/2),'k-',f,abs(fft(x1d))/(Nt/2),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([0. 1.5]);
ylim([0 0.1]);
subplot(2,3,4);
plot(f,abs(fft(x1b))/(Nt/2),'k-o',f,abs(fft(x1d))/(Nt/2),'k--x');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([0.305 0.325]);
ylim([0 0.1]);
subplot(2,3,5);
plot(f,abs(fft(x1b))/(Nt/2),'k-o',f,abs(fft(x1d))/(Nt/2),'k--x');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([0.77 0.82]);
ylim([0 1.4e-2]);
subplot(2,3,6);
plot(f,abs(fft(x1b))/(Nt/2),'k-o',f,abs(fft(x1d))/(Nt/2),'k--x');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([1.26 1.29]);
ylim([0 0.04]);

% Continue with nonlinear damage case
disp('Press any key to continue:');
pause;

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(2*t)+1*sin(5*t)+1*sin(8*t)+1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xb1=x1;
xb2=x2;

mu2=100; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(2*t)+1*sin(5*t)+1*sin(8*t)+1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xd1=x1;
xd2=x2;

% Plot results for discrete Fourier transforms
figure(2);
subplot(211);
plot(f,abs(fft(xb1))/(Nt/2),'k-',f,abs(fft(xd1))/(Nt/2),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([0. 1.5]);
ylim([0 0.1]);
subplot(2,3,4);
plot(f,abs(fft(xb1))/(Nt/2),'k-o',f,abs(fft(xd1))/(Nt/2),'k--x');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([0.305 0.325]);
ylim([0 0.1]);
subplot(2,3,5);
plot(f,abs(fft(xb1))/(Nt/2),'k-o',f,abs(fft(xd1))/(Nt/2),'k--x');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([0.77 0.82]);
ylim([0 1.4e-2]);
subplot(2,3,6);
plot(f,abs(fft(xb1))/(Nt/2),'k-o',f,abs(fft(xd1))/(Nt/2),'k--x');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_1) [m]');
xlim([1.26 1.29]);
ylim([0 0.04]);

% Plot results for transmissibility function
wind=ones(Nt-1,1);
figure(3);
subplot(211);
semilogy(f,abs(fft(xb2.*wind)./fft(xb1.*wind)),'k-',f,abs(fft(xd2.*wind)./fft(xd1.*wind)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_2)/DFT(x_1)');
xlim([0. 1.5]);
ylim([1e-1 1e1]);
subplot(2,3,4);
semilogy(f,abs(fft(xb2.*wind)./fft(xb1.*wind)),'k-',f,abs(fft(xd2.*wind)./fft(xd1.*wind)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_2)/DFT(x_1)');
xlim([0.305 0.325]);
ylim([1e-1 1e1]);
subplot(2,3,5);
semilogy(f,abs(fft(xb2.*wind)./fft(xb1.*wind)),'k-',f,abs(fft(xd2.*wind)./fft(xd1.*wind)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_2)/DFT(x_1)');
xlim([0.77 0.82]);
ylim([1e-1 1e1]);
subplot(2,3,6);
semilogy(f,abs(fft(xb2.*wind)./fft(xb1.*wind)),'k-',f,abs(fft(xd2.*wind)./fft(xd1.*wind)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_2)/DFT(x_1)');
xlim([1.26 1.29]);
ylim([1e-1 1e1]);

% Plot results for frequency response function
wind=ones(Nt-1,1);
figure(4);
semilogy(f,abs(fft(xb2.*wind)./fft(f1(1:Nt-1).*wind)),'k-',f,abs(fft(xd2.*wind)./fft(f1(1:Nt-1).*wind)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. DFT(x_2)/DFT(f_1)');
xlim([0. 1.5]);
ylim([1e-1 1e1]);

% uncomment following lines to plot phase in degrees
% plot(f,180/pi*angle(fft(xb2)./fft(xb1)),'k-',f,180/pi*angle(fft(xd2)./fft(xd1)),'k--');
% xlabel('Frequency [Hz]');
% ylabel('Phs. DFT(x_2)/DFT(x_1) [deg]');
% xlim([0 1.5]);