% Two degree of freedom
% Direct Parameter Estimation model (data driven)
% 4/2/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=1;
k1=10;
k2=20;
k3=10;

% Generate matrices
M=[m1 0;0 m2];
K=[k1+k2 -k2; -k2 k2+k3];
C=.01*M+.01*K;
c1=C(1,1)+C(1,2);
c2=-C(1,2);
c3=C(2,2)+C(2,1);
A=[zeros(2) eye(2);-inv(M)*K -inv(M)*C];
B=[0 0 1 0]';

% Set initial conditions
% Use an initial condition on the velocity to simluate impact
x10=0;
xd10=0;
x20=0;
xd20=0;

% Generate system in MATLAB
sys=ss(A,B,[eye(4)],zeros(4,1));

% Simulate response
Nt=20480;
dt=.001;
t=(0:dt:(Nt-1)*dt)';
f1=rand(Nt,1);
f1=f1-mean(f1);
[x,t]=lsim(sys,f1,t,[x10 x20 xd10 xd20]');

figure(1);
plot(t,x(:,1),'-k',t,x(:,2),'--k');
xlabel('Time [sec]');
ylabel('x_1 and x_2 [m]');
legend('x_1','x_2');
xlim([0 20]);
ylim([-5e-3 5e-3]);

% Compute derivatives
a1=diff(x(:,3))/dt;
a2=diff(x(:,4))/dt;

% Estimate parameter matrices
Navg=1000;
for ii=1:Navg,
    D1(1+2*(ii-1):2+2*(ii-1),1:8)=[a1(ii) 0 x(ii,3) x(ii,3)-x(ii,4) 0 x(ii,1) x(ii,1)-x(ii,2) 0; 0 a2(ii) 0 x(ii,4)-x(ii,3) x(ii,4) 0 x(ii,2)-x(ii,1) x(ii,2)];
    D2(1+2*(ii-1):2+2*(ii-1),1)=[f1(ii); 0];
end
P=pinv(D1)*D2;

% Output parameters
P

% Compare to actual values
[m1 m2 c1 c2 c3 k1 k2 k3]'