% Two degree of freedom
% Discrete Time model (data driven)
% 4/2/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Parameters
m1=1;
m2=1;
k1=10;
k2=20;
k3=10;

% Generate matrices
M=[m1 0;0 m2];
K=[k1+k2 -k2; -k2 k2+k3];
C=.01*M+.01*K;
c1=C(1,1)+C(1,2);
c2=-C(1,2);
c3=C(2,2)+C(2,1);
A=[zeros(2) eye(2);-inv(M)*K -inv(M)*C];
B=[0 0 1 0]';

% Set initial conditions
% Use an initial condition on the velocity to simluate impact
x10=0;
xd10=0;
x20=0;
xd20=0;

% Generate system in MATLAB
sys=ss(A,B,[eye(4)],zeros(4,1));

% Simulate response
Nt=20480*2;
dt=.1;
Navg=21;
st=15000;
Nsim=300;
t=(0:dt:(Nt-1)*dt)';
f1=sin(2*pi*t)+sin(2*pi*2*t)+sin(2*pi*3*t);
[x,t]=lsim(sys,f1,t,[x10 x20 xd10 xd20]');

figure(1);
subplot(211);
plot(t(st:st+Nsim),x(st:st+Nsim,1),'x-k',t(st:st+Nsim),x(st:st+Nsim,2),'o--k');
xlabel('Time [sec]');
ylabel('x_1(k) and x_2(k) [m]');
legend('x_1','x_2');
xlim([1500 1505]);
ylim([-.08 .08]);

% Estimate parameter matrices
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);

% Simulate response
x1s(1:st+Navg-1)=0;
x1s(1:st)=x(1:st,1);

for ii=1:Nsim,
    x1s(st+ii)=P(1)*x1s(st+ii-1)+P(2)*x1s(st+ii-2)+P(3)*x1s(st+ii-3)+P(4)*x1s(st+ii-4)+P(5)*f1(st+ii)+P(6)*f1(st+ii-1)+P(7)*f1(st+ii-2);
end

figure(1);
subplot(212);
plot(t(st+1-5:st+1+Nsim-1),x1s(st+1-5:st+1+Nsim-1),'+-k',t(st+1-5:st+1+Nsim-1),x(st+1-5:st+1+Nsim-1,1),'x-k');
xlabel('Time [sec]');
ylabel('x_1(k) [m]');
xlim([1500 1505]);
ylim([-.08 .08]);

% Continue on with noise on data
disp('Press any button to continue');
pause;

f1=sin(2*pi*t)+sin(2*pi*2*t)+sin(2*pi*3*t)+randn(Nt,1)*.02;
[x,t]=lsim(sys,f1,t,[x10 x20 xd10 xd20]');

% Estimate parameter matrices
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);

% Simulate response
x1s(1:st+Navg-1)=0;
x1s(1:st)=x(1:st,1);

for ii=1:Nsim,
    x1s(st+ii)=P(1)*x1s(st+ii-1)+P(2)*x1s(st+ii-2)+P(3)*x1s(st+ii-3)+P(4)*x1s(st+ii-4)+P(5)*f1(st+ii)+P(6)*f1(st+ii-1)+P(7)*f1(st+ii-2);
end

figure(2);
plot(t(st+1-5:st+1+Nsim-1),x1s(st+1-5:st+1+Nsim-1),'+-k',t(st+1-5:st+1+Nsim-1),x(st+1-5:st+1+Nsim-1,1),'x-k'); hold on;
xlabel('Time [sec]');
ylabel('x_1(k) [m]');
xlim([1500 1505]);
ylim([-.08 .08]);

f1=sin(2*pi*t)+sin(2*pi*2*t)+sin(2*pi*3*t)+randn(Nt,1)*.05;
[x,t]=lsim(sys,f1,t,[x10 x20 xd10 xd20]');

% Estimate parameter matrices
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);

% Simulate response
x1s(1:st+Navg-1)=0;
x1s(1:st)=x(1:st,1);

for ii=1:Nsim,
    x1s(st+ii)=P(1)*x1s(st+ii-1)+P(2)*x1s(st+ii-2)+P(3)*x1s(st+ii-3)+P(4)*x1s(st+ii-4)+P(5)*f1(st+ii)+P(6)*f1(st+ii-1)+P(7)*f1(st+ii-2);
end

figure(2);
plot(t(st+1-5:st+1+Nsim-1),x1s(st+1-5:st+1+Nsim-1),'+-k',t(st+1-5:st+1+Nsim-1),x(st+1-5:st+1+Nsim-1,1),'x-k'); hold on;
xlabel('Time [sec]');
ylabel('x_1(k) [m]');
xlim([1500 1505]);
ylim([-.08 .08]);

f1=sin(2*pi*t)+sin(2*pi*2*t)+sin(2*pi*3*t)+randn(Nt,1)*.1;
[x,t]=lsim(sys,f1,t,[x10 x20 xd10 xd20]');

% Estimate parameter matrices
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);

% Simulate response
x1s(1:st+Navg-1)=0;
x1s(1:st)=x(1:st,1);

for ii=1:Nsim,
    x1s(st+ii)=P(1)*x1s(st+ii-1)+P(2)*x1s(st+ii-2)+P(3)*x1s(st+ii-3)+P(4)*x1s(st+ii-4)+P(5)*f1(st+ii)+P(6)*f1(st+ii-1)+P(7)*f1(st+ii-2);
end

figure(2);
plot(t(st+1-5:st+1+Nsim-1),x1s(st+1-5:st+1+Nsim-1),'+-k',t(st+1-5:st+1+Nsim-1),x(st+1-5:st+1+Nsim-1,1),'x-k'); hold on;
xlabel('Time [sec]');
ylabel('x_1(k) [m]');
xlim([1500 1505]);
ylim([-.08 .08]);
