% Two degree of freedom model
% Eigenvalue and eigenvector solution
% 3/25/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Define parameters
m1=1;
m2=1;
k1=10;
k2=20;
k3=10;

% Generate matrices
M=[m1 0;0 m2];
K=[k1+k2 -k2; -k2 k2+k3];
C=.01*M+.01*K;
A=[zeros(2) eye(2);-inv(M)*K -inv(M)*C];

% Solve for eigenvalues (d) and eigenvectors (v)
[v,d]=eig(A);

% Find natural frequencies and deflection shapes
d(3,3)
d(1,1)
v(1:2,3)/v(1,3)
v(1:2,1)/v(1,1)

% Continue on with variation in eigen-properties as K1 and K2 change
disp('Press any button to continue');
pause;

% Calculate and plot change in natural frequency with stiffnesses K1
k1=10:-1:5;
for ii=1:max(size(k1)),
    K=[k1(ii)+k2 -k2; -k2 k2+k3];
    C=.01*M+.01*K;
    A=[zeros(2) eye(2);-inv(M)*K -inv(M)*C];
    [v,d]=eig(A);
    wd(:,ii)=abs(imag([d(3,3) d(1,1)]'));
end
figure (1);
subplot(211);
plot(k1,wd(1,:),'k-x',k1,wd(2,:),'k--x');
xlabel('K_1 [N/m]');
ylabel('Natural Freqs. [rad/s]');
ylim([2 8]);

% Calculate and plot change in natural frequency with stiffnesses K1
clear wd;
k1=10;
k2=20:-1:10;
for ii=1:max(size(k2)),
    K=[k1+k2(ii) -k2(ii); -k2(ii) k2(ii)+k3];
    C=.01*M+.01*K;
    A=[zeros(2) eye(2);-inv(M)*K -inv(M)*C];
    [v,d]=eig(A);
    wd(:,ii)=abs(imag([d(3,3) d(1,1)]'));
end
figure(1);
subplot(212);
plot(k2,wd(1,:),'k-x',k2,wd(2,:),'k--x');
xlabel('K_2 [N/m]');
ylabel('Natural Freqs. [rad/s]');
ylim([2 8]);