% Two degree of freedom
% Time-delay embedding analysis
% 5/18/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector

% Simulate restoring forces for joint damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(8*t)+1*sin(2*t);

% Simulate linear model
sim('two_dof_model_nl');

x1b=x1;

% Plot results
Stp=20000; Enp=25000;
del=40;
figure(1);
subplot(211);
plot3(x1(Stp-del:Enp-del),x1(Stp-2*del:Enp-2*del),x1(Stp:Enp),'k.'); hold on;
ylabel('x(n-2)');
xlabel('x(n-1)');
zlabel('x(n)');
view(152,-50)
subplot(212);
del=120;
plot3(x1(Stp-del:Enp-del),x1(Stp-2*del:Enp-2*del),x1(Stp:Enp),'k.'); hold on;
ylabel('x(n-2)');
xlabel('x(n-1)');
zlabel('x(n)');
view(-132,14);

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=20; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(8*t)+1*sin(2*t);

% Simulate linear model
sim('two_dof_model_nl');

del=40;
ind1(1)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));
del=120;
ind2(1)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));

mu2=50; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(8*t)+1*sin(2*t);

% Simulate linear model
sim('two_dof_model_nl');

del=40;
ind1(2)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));
del=120;
ind2(2)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));

mu2=80; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(8*t)+1*sin(2*t);

% Simulate linear model
sim('two_dof_model_nl');

del=40;
ind1(3)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));
del=120;
ind2(3)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));

mu2=120; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(8*t)+1*sin(2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Plot results
figure(1);
subplot(211);
del=40;
plot3(x1(Stp-del:Enp-del),x1(Stp-2*del:Enp-2*del),x1(Stp:Enp),'c.');
ylabel('x(n-2)');
xlabel('x(n-1)');
zlabel('x(n)');
view(152,-50)
subplot(212);
del=120;
plot3(x1(Stp-del:Enp-del),x1(Stp-2*del:Enp-2*del),x1(Stp:Enp),'c.');
ylabel('x(n-2)');
xlabel('x(n-1)');
zlabel('x(n)');
view(-132,14);

del=40;
ind1(4)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));
del=120;
ind2(4)=sum(sqrt((x1(Stp:Enp)-x1b(Stp:Enp)).^2+(x1(Stp-del:Enp-del)-x1b(Stp-del:Enp-del)).^2+(x1(Stp-2*del:Enp-2*del)-x1b(Stp-2*del:Enp-2*del)).^2));

figure(2);
plot([20 50 80 120],ind1,'k-x',[20 50 80 120],ind2,'k-o');
xlabel('\mu_2');
ylabel('Cum. Distance');