% Simulate to obtain FRFs for
% two degree of freedom system with nonlinear 
% joint and damage
%
clear all;
close all;

% Create time simulation parameters and excitation force
Nt=2^17;                                       % Number of time points
BS=1024*10;                                    % Size of data blocks
navg=30;                                       % Number of averages
ovlap=(Nt/BS-navg)/(1-navg);                   % Data block parameters
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector
fv=(0:1/t(BS):(BS-1)/t(BS))';                  % Frequency vector

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Input
f1=1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

% Calculate FRFs
[frf_lin1,coh_lin1]=rfrf(f1,x1,navg,ovlap);
[frf_lin2,coh_lin2]=rfrf(f1,x2,navg,ovlap);

% semilogy linear FRFs
figure(1);
subplot(211);
semilogy(fv(1:BS/2),abs(frf_lin1(1:BS/2)),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. H_{11} [m/N]'); 
xlim([0 3]);
ylim([1e-3 1e0]);
subplot(212);
semilogy(fv(1:BS/2),abs(frf_lin2(1:BS/2)),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. H_{21} [m/N]');
xlim([0 3]);
ylim([1e-3 1e0]);

% Coulomb friction in joint 2
mu1=.05;

% Simulate nonlinear model
sim('two_dof_model_nl');

% Calculate FRFs
[frf_lin1,coh_lin1]=rfrf(f1,x1,navg,ovlap);
[frf_lin2,coh_lin2]=rfrf(f1,x2,navg,ovlap);

% semilogy linear FRFs
figure(1);
subplot(211);
semilogy(fv(1:BS/2),abs(frf_lin1(1:BS/2)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{11} [m/N]'); 
xlim([0 3]);
ylim([1e-3 1e0]);
subplot(212);
semilogy(fv(1:BS/2),abs(frf_lin2(1:BS/2)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{21} [m/N]');
xlim([0 3]);
ylim([1e-3 1e0]);

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Input
f1=1*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

% Calculate FRFs
[frf_lin1,coh_lin1]=rfrf(f1,x1,navg,ovlap);
[frf_lin2,coh_lin2]=rfrf(f1,x2,navg,ovlap);

% semilogy linear FRFs
figure(2);
subplot(211);
semilogy(fv(1:BS/2),abs(frf_lin1(1:BS/2)),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. H_{11} [m/N]'); 
xlim([0 3]);
ylim([1e-3 1e0]);
subplot(212);
semilogy(fv(1:BS/2),abs(frf_lin2(1:BS/2)),'k-'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. H_{21} [m/N]');
xlim([0 3]);
ylim([1e-3 1e0]);

% Buckling of panel
mu2=500;

% Simulate nonlinear model
sim('two_dof_model_nl');

% Calculate FRFs
[frf_lin1,coh_lin1]=rfrf(f1,x1,navg,ovlap);
[frf_lin2,coh_lin2]=rfrf(f1,x2,navg,ovlap);

% semilogy linear FRFs
figure(2);
subplot(211);
semilogy(fv(1:BS/2),abs(frf_lin1(1:BS/2)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{11} [m/N]'); 
xlim([0 3]);
ylim([1e-3 1e0]);
subplot(212);
semilogy(fv(1:BS/2),abs(frf_lin2(1:BS/2)),'k--');
xlabel('Frequency [Hz]');
ylabel('Mag. H_{21} [m/N]');
xlim([0 3]);
ylim([1e-3 1e0]);
