% Two degree of freedom
% Restoring Force model (data driven)
% 4/2/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
BS=1024*10;                                    % Size of data blocks
navg=30;                                       % Number of averages
ovlap=(Nt/BS-navg)/(1-navg);                   % Data block parameters
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector
fv=(0:1/t(BS):(BS-1)/t(BS))';                  % Frequency vector
w1=2;
w2=8;

% Simulate restoring forces for joint damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Input
f1=1*sin(w1*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
Spt=20000; Ept=21000;
figure(1);
subplot(211);
plot(v2(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('v_2 [m/s]');
ylabel('a_2 [m/s^2]');
xlim([-.2 .2]);
ylim([-2 2]);

% Input
f1=1*sin(w2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
subplot(212);
plot(v2(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('v_2 [m/s]');
ylabel('a_2 [m/s^2]');
xlim([-.2 .2]);
ylim([-2 2]);

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0.2; % Coulomb friction
mu2=0; % Crack

% Input
f1=1*sin(w1*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
Spt=20000; Ept=21000;
subplot(211);
plot(v2(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('v_2 [m/s]');
ylabel('a_2 [m/s^2]');
xlim([-.2 .2]);
ylim([-2 2]);

% Input
f1=1*sin(w2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
subplot(212);
plot(v2(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('v_2 [m/s]');
ylabel('a_2 [m/s^2]');
xlim([-.2 .2]);
ylim([-2 2]);

% Simulate restoring forces for buckling damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Input
f1=1*sin(w1*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
Spt=20000; Ept=21000;
figure(2);
subplot(211);
plot(x2(Spt:Ept)-x1(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('x_2-x_1 [m]');
ylabel('a_2 [m/s^2]');
xlim([-.04 .04]);
ylim([-.4 .4]);

% Input
f1=1*sin(w2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
subplot(212);
plot(x2(Spt:Ept)-x1(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('x_2-x_1 [m]');
ylabel('a_2 [m/s^2]');
xlim([-.1 .1]);
ylim([-2 2]);

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=100; % Crack

% Input
f1=1*sin(w1*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
Spt=20000; Ept=21000;
subplot(211);
plot(x2(Spt:Ept)-x1(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('x_2-x_1 [m]');
ylabel('a_2 [m/s^2]');
xlim([-.04 .04]);
ylim([-.4 .4]);

% Input
f1=1*sin(w2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
subplot(212);
plot(x2(Spt:Ept)-x1(Spt:Ept),a2(Spt:Ept),'-k'); hold on;
xlabel('x_2-x_1 [m]');
ylabel('a_2 [m/s^2]');
xlim([-.1 .1]);
ylim([-2 2]);

% Simulate phase plane trajectories for buckling damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Input
f1=1*sin(w1*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
Spt=20000; Ept=21000;
figure(3);
subplot(211);
plot(x2(Spt:Ept),v2(Spt:Ept),'-k'); hold on;
xlabel('x_2 [m]');
ylabel('v_2 [m/s]');
ylim([-.2 .2]);
xlim([-.1 .1]);

% Input
f1=1*sin(w2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
subplot(212);
plot(x2(Spt:Ept),v2(Spt:Ept),'-k'); hold on;
xlabel('x_2 [m]');
ylabel('v_2 [m/s]');
ylim([-.2 .2]);
xlim([-.04 .04]);

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=100; % Crack

% Input
f1=1*sin(w1*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
Spt=20000; Ept=21000;
subplot(211);
plot(x2(Spt:Ept),v2(Spt:Ept),'-k'); hold on;
xlabel('x_2 [m]');
ylabel('v_2 [m/s]');
ylim([-.2 .2]);
xlim([-.1 .1]);

% Input
f1=1*sin(w2*t);

% Simulate linear model
sim('two_dof_model_nl');

% Differentiate to obtain velocity and acceleration
v1=diff(x1)/dt;
v2=diff(x2)/dt;
a1=diff(v1)/dt;
a2=diff(v2)/dt;

% Draw restoring forces
subplot(212);
plot(x2(Spt:Ept),v2(Spt:Ept),'-k'); hold on;
xlabel('x_2 [m]');
ylabel('v_2 [m/s]');
ylim([-.2 .2]);
xlim([-.04 .04]);
