% Two degree of freedom
% Temporal analysis
% 5/18/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Create time vector and excitation force
Nt=2^17;                                       % Number of time points
Fs=256; dt=1/Fs;                               % Sampling frequency and time step
t=(0:dt:((Nt-1)*dt))';                         % Time vector

% Simulate restoring forces for joint damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

for ii=1:5,

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(2*t)+1*sin(5*t)+1*sin(8*t)+randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

% Calculate statistical parameters
mu1=mean(x1);
mu2=mean(x2);
rms1=sqrt(mean(x1.^2));
rms2=sqrt(mean(x2.^2));
var1=var(x1);
var2=var(x2);
g1=Nt*sum((x1-mu1).^3)/sum((x1-mu1).^2)^(3/2);
g2=Nt*sum((x2-mu2).^3)/sum((x2-mu2).^2)^(3/2);
rmsd=sqrt(mean((x1-x2).^2));
R12=mean(x1.*x2);
C12=mean((x1-mu1).*(x2-mu2));

pars(:,ii)=[mu1; mu2; rms1; rms2; var1; var2; g1; g2; rmsd; R12; C12];

end

x1b=x1;
x2b=x2;

% Simulate restoring forces for joint damage
% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20-20*0.10;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

for ii=1:5,

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=sin(2*t)+sin(5*t)+sin(8*t)+randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

% Calculate statistical parameters
mu1=mean(x1);
mu2=mean(x2);
rms1=sqrt(mean(x1.^2));
rms2=sqrt(mean(x2.^2));
var1=var(x1);
var2=var(x2);
g1=Nt*sum((x1-mu1).^3)/sum((x1-mu1).^2)^(3/2);
g2=Nt*sum((x2-mu2).^3)/sum((x2-mu2).^2)^(3/2);
rmsd=sqrt(mean((x1-x2).^2));
R12=mean(x1.*x2);
C12=mean((x1-mu1).*(x2-mu2));

parsd(:,ii)=[mu1; mu2; rms1; rms2; var1; var2; g1; g2; rmsd; R12; C12];

end

x1d=x1;
x2d=x2;

% Plot results
figure(1);
subplot(6,2,1);
plot(1:5,pars(1,:),'k-o',1:5,parsd(1,:),'k--x');
ylabel('\mu_1');
subplot(6,2,2);
plot(1:5,pars(2,:),'k-o',1:5,parsd(2,:),'k--x');
ylabel('\mu_2');
subplot(6,2,3);
plot(1:5,pars(3,:),'k-o',1:5,parsd(3,:),'k--x');
ylabel('rms_1');
subplot(6,2,4);
plot(1:5,pars(4,:),'k-o',1:5,parsd(4,:),'k--x');
ylabel('rms_2');
subplot(6,2,5);
plot(1:5,pars(5,:),'k-o',1:5,parsd(5,:),'k--x');
ylabel('\sigma_1');
subplot(6,2,6);
plot(1:5,pars(6,:),'k-o',1:5,parsd(6,:),'k--x');
ylabel('\sigma_2');
subplot(6,2,7);
plot(1:5,pars(7,:),'k-o',1:5,parsd(7,:),'k--x');
ylabel('g_1');
subplot(6,2,8);
plot(1:5,pars(8,:),'k-o',1:5,parsd(8,:),'k--x');
ylabel('g_2');
subplot(6,2,9);
plot(1:5,pars(9,:),'k-o',1:5,parsd(9,:),'k--x');
ylabel('rms_d');
subplot(6,2,10);
plot(1:5,pars(10,:),'k-o',1:5,parsd(10,:),'k--x');
ylabel('R_{12}');
subplot(6,2,11);
plot(1:5,pars(11,:),'k-o',1:5,parsd(11,:),'k--x');
ylabel('C_{12}');
xlabel('Data Set');

figure(2);
plot(t(1:Nt-1),x1b,'k-',t(1:Nt-1),x1d,'k--');
xlabel('Time [s]');
ylabel('x_1 [m]');

% Continue with deterministic analysis techniques
disp('Press any key to continue:');
pause;

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(5*t)+0.05*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xb1=x1;
xb2=x2;

mu2=150; % Crack

% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(5*t)+0.05*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');

xd1=x1;
xd2=x2;

% Generate velocity and displacement variables
vb1=diff(xb1)/dt;
vb2=diff(xb2)/dt;
vd1=diff(xd1)/dt;
vd2=diff(xd2)/dt;
ab1=diff(vb1)/dt;
ab2=diff(vb2)/dt;
ad1=diff(vd1)/dt;
ad2=diff(vd2)/dt;

% Draw restoring forces
Spt=20000; Ept=20330;
figure(3);
subplot(221);
plot(vb2(Spt:Ept)-vb1(Spt:Ept),ab1(Spt:Ept),'-k',vd2(Spt:Ept)-vd1(Spt:Ept),ad1(Spt:Ept),':k'); hold on;
xlabel('v_2-v_1 [m/s]');
ylabel('a_1 [m/s^2]');
xlim([-.3 .3]);
ylim([-1 1]);
subplot(222);
plot(xb2(Spt:Ept)-xb1(Spt:Ept),ab1(Spt:Ept),'-k',xd2(Spt:Ept)-xd1(Spt:Ept),ad1(Spt:Ept),':k'); hold on;
xlabel('x_2-x_1 [m]');
ylabel('a_1 [m/s^2]');
xlim([-.05 .05]);
ylim([-1 1]);
subplot(223);
plot(vb2(Spt:Ept)-vb1(Spt:Ept),ab2(Spt:Ept),'-k',vd2(Spt:Ept)-vd1(Spt:Ept),ad2(Spt:Ept),':k'); hold on;
xlabel('v_2-v_1 [m/s]');
ylabel('a_2 [m/s^2]');
xlim([-.3 .3]);
ylim([-2 2]);
subplot(224);
plot(xb2(Spt:Ept)-xb1(Spt:Ept),ab2(Spt:Ept),'-k',xd2(Spt:Ept)-xd1(Spt:Ept),ad2(Spt:Ept),':k'); hold on;
xlabel('x_2-x_1 [m]');
ylabel('a_2 [m/s^2]');
xlim([-.05 .05]);
ylim([-2 2]);

% Compute areas of baseline and damaged datasets
[ymin,inmin]=min(xb2(Spt:Ept)-xb1(Spt:Ept));
[ymax,inmax]=max(xb2(Spt:Ept)-xb1(Spt:Ept));
[ymin2,inmin2]=min(xb2(Spt-1+inmax:Ept)-xb1(Spt-1+inmax:Ept));
delt1=ymax-ymin;
no1=abs(inmax-inmin);

intdown=trapz(ab2(Spt-1+inmin:Spt-1+inmax));
intup=trapz(ab2(Spt-1+inmax-1:Spt-1+inmax-1+inmin2));
inttotb=abs(intdown)+abs(intup);
inttotb=inttotb*delt1/no1;

[ymin,inmin]=min(xd2(Spt:Ept)-xd1(Spt:Ept));
[ymax,inmax]=max(xd2(Spt:Ept)-xd1(Spt:Ept));
[ymin2,inmin2]=min(xd2(Spt-1+inmax:Ept)-xd1(Spt-1+inmax:Ept));
delt2=ymax-ymin;
no2=abs(inmax-inmin);

intdown=trapz(ad2(Spt-1+inmin:Spt-1+inmax));
intup=trapz(ad2(Spt-1+inmax-1:Spt-1+inmax-1+inmin2));
inttotd=abs(intdown)+abs(intup);
inttotd=inttotd*delt2/no2;

% Continue with discrete time model
disp('Press any key to continue:');
pause;

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

for kk=1:10,
    
% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(5*t)+0.05*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');
x=[x1 x2];

% Estimate parameter matrices
Navg=21;
st=20000;
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2;

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);
Pb(:,kk)=P;

end

mu2=150; % Crack

for kk=1:10,
    
% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(5*t)+0.05*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');
x=[x1 x2];

% Estimate parameter matrices
Navg=21;
st=20000;
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2;

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);
Pd(:,kk)=P;

end

figure(4);
subplot(211);
plot([Pb(:,1:10) Pd(:,1:10)]');
xlabel('Dataset');
ylabel('Parameters');
xlim([1 20]);
subplot(212);
plot(1:7,var(Pb(:,1:10)'),'k-o',1:7,var(Pd(:,1:10)'),'k-x');
xlabel('Parameter');
ylabel('Variance');

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

for kk=1:10,
    
% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(5*t)+0.05*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');
x=[x1 x2];

% Estimate parameter matrices
Navg=21;
st=20000;
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2;

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);
Pb(:,kk)=P;

end

% Linear parameters
M1=1;
M2=1;
K1=10;
K2=20-20*0.10;
K3=10;
M=[M1 0;0 M2];
K=[K1+K2 -K2;-K2 K2+K3];
C=.02*M+.02*K;
C2=-C(1,2);
C1=C(1,1)-C2;
C3=C(2,2)-C2;
mu1=0; % Coulomb friction
mu2=0; % Crack

for kk=1:10,
    
% Reset the state of random number generator
randn('state',sum(100*clock));

% Input
f1=1*sin(5*t)+0.05*randn(Nt,1);

% Simulate linear model
sim('two_dof_model_nl');
x=[x1 x2];

% Estimate parameter matrices
Navg=21;
st=20000;
for ii=1:Navg,
    D1(1+(ii-1)*1,1:7)=[x(st+ii-1,1) x(st+ii-2,1) x(st+ii-3,1) x(st+ii-4,1) f1(st+ii) f1(st+ii-1) f1(st+ii-2)];
    D2(1+(ii-1)*1,1)=[x(st+ii,1)];
end

% Normalize columns by standard deviation
stdnorm=std(D1);
D1(:,1)=D1(:,1)/stdnorm(1);
D1(:,2)=D1(:,2)/stdnorm(2);
D1(:,3)=D1(:,3)/stdnorm(3);
D1(:,4)=D1(:,4)/stdnorm(4);
D1(:,5)=D1(:,5)/stdnorm(5);
D1(:,6)=D1(:,6)/stdnorm(6);
D1(:,7)=D1(:,7)/stdnorm(7);
P=pinv(D1)*D2;

% Output parameters
P(1)=P(1)/stdnorm(1);
P(2)=P(2)/stdnorm(2);
P(3)=P(3)/stdnorm(3);
P(4)=P(4)/stdnorm(4);
P(5)=P(5)/stdnorm(5);
P(6)=P(6)/stdnorm(6);
P(7)=P(7)/stdnorm(7);
Pd(:,kk)=P;

end

figure(5);
subplot(211);
plot([Pb(:,1:10) Pd(:,1:10)]');
xlabel('Dataset');
ylabel('Parameters');
xlim([1 20]);
ylim([-2 3]);
subplot(212);
plot(1:7,var(Pb(:,1:10)')','k-o',1:7,var(Pd(:,1:10)')','k-x');
xlabel('Parameter');
ylabel('Variance');