% Two degree of freedom model with sensor
% Impedance and compliance modeling analysis
% 4/8/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% System parameters
m1=1;
m2=1;
k1=10;
k2=20;
k3=10;

% Sensor parameters
ms=.05*m2;
ks=k2*5;

% Generate matrices
M=[m1 0 0;0 m2 0;0 0 ms];
K=[k1+k2 -k2 0; -k2 k2+k3+ks -ks;0 -ks ks];
C=.01*M+.01*K;

% Construct frequency vector in rad/sec
w=(0:.05:100)';

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

sqrt(eig(-inv(M)*K))/2/pi

figure(1);
subplot(211);
semilogy(w/2/pi,abs(squeeze(H(1,1,:))),'k--'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. H_{11} [m/N]');
xlim([0.25 1.75]);
ylim([1e-3 1e1]);
subplot(212);
semilogy(w/2/pi,abs(squeeze(H(2,1,:))),'k--'); hold on;
xlabel('Frequency [Hz]');
ylabel('Mag. H_{21} [m/N]');
xlim([0.25 1.75]);
ylim([1e-3 1e1]);

% Sensor parameters
ms=0*m2;
ks=k2*2;

% Generate matrices
M=[m1 0 0;0 m2 0;0 0 ms];
K=[k1+k2 -k2 0; -k2 k2+k3+ks -ks;0 -ks ks];
C=.01*M+.01*K;

% Invert the impedance matrix at each frequency
for ii=1:max(size(w)),
    H(1:3,1:3,ii)=inv(-w(ii)^2*M+j*w(ii)*C+K);
end

figure(1);
subplot(211);
semilogy(w/2/pi,abs(squeeze(H(1,1,:))),'k-');
subplot(212);
semilogy(w/2/pi,abs(squeeze(H(2,1,:))),'k-');