% Plot time domain weighting functions and
% results for application of windows to reduce leakage
% 5/23/06 
% 2006 Copyright D. E. Adams

clear all;
close all;

% Define DFT parameters
BS=1000;
t=(0:.001:.999)';
[m,n]=size(t);
f=(-m/t(m)/2:1/t(m):m/t(m)/2-1/t(m))';

% Define P301 window function
ftv=linspace(-0.5,0.5,BS)';
tmp2=0.9994484+2*(0.955728*cos(2*pi*1*ftv)+0.539289*cos(2*pi*2*ftv)+0.091581*cos(2*pi*3*ftv));

% Define fully observed time history
y1=sin(2*pi*t/.1);
 
% Compute DFT
Y1f=fft(y1)/(m/2);

% Plot results for no window applied
figure(1);
subplot(211);
plot(t,y1,'kx-'); xlabel('Time [sec]'); ylabel('y(t)');
subplot(212);
semilogy(f,fftshift(abs(Y1f)),'kx-'); 
xlabel('Frequency [Hz]'); ylabel('Mag [DFT Y(f)]');
axis([0 50 1e-20 1e2]);

% Define partially observed time history
y2=sin(2*pi*t/.15);

% Compute DFT
Y2f=fft(y2)/(m/2);

% Plot results for no window and other windows applied
figure(2);
subplot(211);
plot(t,y2,'kx-'); xlabel('Time [sec]'); ylabel('y(t)');
subplot(212);
semilogy(f,fftshift(abs(Y2f)),'kx-'); 
xlabel('Frequency [Hz]'); ylabel('Mag [DFT Y(f)]');
axis([0 50 1e-20 1e2]);

figure(3);
semilogy(f,fftshift(abs(Y2f)),'kx-'); hold on;
semilogy(f,fftshift(abs(fft(hanning(BS).*y2)))/(m/2),'ko-');
semilogy(f,fftshift(abs(fft(tmp2(1:BS).*y2)))/(m/2),'k+-'); 
xlabel('Frequency [Hz]'); ylabel('Mag [DFT Y(f)]'); 
axis([0 50 1e-8 1e2]);

figure(4)
plot(t,ones(BS,1),'k-',t,hanning(BS),'k--',t,tmp2,'k:'); xlabel('Time [sec]'); ylabel('w(t)');
axis([0 1 -2 5]);